@@ -1,7 +1,7 @@
 #include "evas_common.h"
 #include "evas_private.h"
+#include "evas_cs.h"
 
-extern Evas_List *evas_modules;
 static int initcount = 0;
 
 EAPI int
@@ -9,8 +9,13 @@ evas_init(void)
 {
    if (initcount == 0)
      {
+	eina_init();
+
 	evas_module_init();
 	evas_async_events_init();
+#ifdef EVAS_CSERVE
+        if (getenv("EVAS_CSERVE")) evas_cserve_init();
+#endif        
      }
    return ++initcount;
 }
@@ -21,16 +26,20 @@ evas_shutdown(void)
    initcount--;
    if (initcount == 0)
      {
+#ifdef EVAS_CSERVE
+        if (getenv("EVAS_CSERVE")) evas_cserve_shutdown();
+#endif        
 	evas_async_events_shutdown();
 	evas_font_dir_cache_free();
 	evas_common_shutdown();
 	evas_module_shutdown();
+	eina_shutdown();
      }
    return initcount;
 }
 
 /**
- * @defgroup Evas_Canvas Evas Canvas
+ * @defgroup Evas_Canvas Evas Canvas functions
  *
  * Functions that deal with the basic evas object.  They are the
  * functions you need to use at a minimum to get a working evas, and
@@ -66,15 +75,17 @@ evas_new(void)
    e->viewport.w = 1;
    e->viewport.h = 1;
    e->hinting = EVAS_FONT_HINTING_BYTECODE;
+   e->name_hash = eina_hash_string_superfast_new(NULL);
 
-   evas_array_setup(&e->delete_objects, 16);
-   evas_array_setup(&e->active_objects, 16);
-   evas_array_setup(&e->restack_objects, 16);
-   evas_array_setup(&e->render_objects, 16);
-   evas_array_setup(&e->pending_objects, 16);
-   evas_array_setup(&e->obscuring_objects, 16);
-   evas_array_setup(&e->temporary_objects, 16);
-   evas_array_setup(&e->calculate_objects, 16);
+   eina_array_step_set(&e->delete_objects, 16);
+   eina_array_step_set(&e->active_objects, 16);
+   eina_array_step_set(&e->restack_objects, 16);
+   eina_array_step_set(&e->render_objects, 16);
+   eina_array_step_set(&e->pending_objects, 16);
+   eina_array_step_set(&e->obscuring_objects, 16);
+   eina_array_step_set(&e->temporary_objects, 16);
+   eina_array_step_set(&e->calculate_objects, 16);
+   eina_array_step_set(&e->clip_changes, 16);
 
    return e;
 }
@@ -91,7 +102,8 @@ evas_new(void)
 EAPI void
 evas_free(Evas *e)
 {
-   Evas_Object_List *l;
+   Eina_Rectangle *r;
+   Evas_Layer *lay;
    int i;
    int del;
 
@@ -108,18 +120,14 @@ evas_free(Evas *e)
    while (del)
      {
 	del = 0;
-	for (l = (Evas_Object_List *)(e->layers); l; l = l->next)
+	EINA_INLIST_FOREACH(e->layers, lay)
 	  {
-	     Evas_Layer *lay;
-	     Evas_Object_List *ll;
+	     Evas_Object *o;
 
-	     lay = (Evas_Layer *)l;
 	     evas_layer_pre_free(lay);
-	     for (ll = (Evas_Object_List *)lay->objects; ll; ll = ll->next)
-	       {
-		  Evas_Object *o;
 
-		  o = (Evas_Object *)ll;
+	     EINA_INLIST_FOREACH(lay->objects, o)
+	       {
 		  if ((o->callbacks) && (o->callbacks->walking_list))
 		    {
 		       /* Defer free */
@@ -132,33 +140,26 @@ evas_free(Evas *e)
 	       }
 	  }
      }
-   while (e->layers)
-     {
-	Evas_Layer *lay;
+   EINA_INLIST_FOREACH(e->layers, lay)
+     evas_layer_free_objects(lay);
+   evas_layer_clean(e);
 
-	lay = e->layers;
-	evas_layer_del(lay);
-	evas_layer_free(lay);
-     }
    e->walking_list--;
-   
+
    evas_font_path_clear(e);
-   e->pointer.object.in = evas_list_free(e->pointer.object.in);
+   e->pointer.object.in = eina_list_free(e->pointer.object.in);
 
-   if (e->name_hash) evas_hash_free(e->name_hash);
+   if (e->name_hash) eina_hash_free(e->name_hash);
+   e->name_hash = NULL;
 
-   while (e->damages)
-     {
-	free(e->damages->data);
-	e->damages = evas_list_remove(e->damages, e->damages->data);
-     }
-   while (e->obscures)
-     {
-	free(e->obscures->data);
-	e->obscures = evas_list_remove(e->obscures, e->obscures->data);
-     }
+   EINA_LIST_FREE(e->damages, r)
+     eina_rectangle_free(r);
+   EINA_LIST_FREE(e->obscures, r)
+     eina_rectangle_free(r);
 
-   if (e->engine.func) 
+   evas_fonts_zero_free(e);
+
+   if (e->engine.func)
      {
 	e->engine.func->info_free(e, e->engine.info);
 	e->engine.func->context_free(e->engine.data.output, e->engine.data.context);
@@ -175,13 +176,15 @@ evas_free(Evas *e)
 
    if (e->engine.module) evas_module_unref(e->engine.module);
 
-   evas_array_flush(&e->delete_objects);
-   evas_array_flush(&e->active_objects);
-   evas_array_flush(&e->restack_objects);
-   evas_array_flush(&e->render_objects);
-   evas_array_flush(&e->pending_objects);
-   evas_array_flush(&e->obscuring_objects);
-   evas_array_flush(&e->temporary_objects);
+   eina_array_flush(&e->delete_objects);
+   eina_array_flush(&e->active_objects);
+   eina_array_flush(&e->restack_objects);
+   eina_array_flush(&e->render_objects);
+   eina_array_flush(&e->pending_objects);
+   eina_array_flush(&e->obscuring_objects);
+   eina_array_flush(&e->temporary_objects);
+   eina_array_flush(&e->calculate_objects);
+   eina_array_flush(&e->clip_changes);
 
    e->magic = 0;
    free(e);
@@ -229,7 +232,8 @@ evas_free(Evas *e)
 EAPI void
 evas_output_method_set(Evas *e, int render_method)
 {
-   Evas_List *l;
+   Evas_Module *em;
+
    MAGIC_CHECK(e, Evas, MAGIC_EVAS);
    return;
    MAGIC_CHECK_END();
@@ -238,29 +242,22 @@ evas_output_method_set(Evas *e, int render_method)
    if (render_method == RENDER_METHOD_INVALID) return;
    /* if the engine is already set up - abort */
    if (e->output.render_method != RENDER_METHOD_INVALID) return;
-   /* iterate trough the list to find the id */
-   for (l = evas_modules; l; l = l->next)
-     {
-	Evas_Module *em;
-	Evas_Module_Engine *eme;
-	
-	em = l->data;
-	if (em->type != EVAS_MODULE_TYPE_ENGINE) continue;
-	if (!em->data) continue;
-	eme = (Evas_Module_Engine *)em->data;
-	if (eme->id != render_method) continue;
-	if (!evas_module_load(em)) return;
-	/* set the correct render */
-	e->output.render_method = render_method;
-	e->engine.func = (em->functions);
-	evas_module_use(em);
-	if (e->engine.module) evas_module_unref(e->engine.module);
-	e->engine.module = em;
-	evas_module_ref(em);
-	/* get the engine info struct */
-	if (e->engine.func->info) e->engine.info = e->engine.func->info(e);
-	return;
-     }
+   /* Request the right engine. */
+   em = evas_module_engine_get(render_method);
+   if (!em) return ;
+   if (em->id_engine != render_method) return;
+   if (!evas_module_load(em)) return;
+
+   /* set the correct render */
+   e->output.render_method = render_method;
+   e->engine.func = (em->functions);
+   evas_module_use(em);
+   if (e->engine.module) evas_module_unref(e->engine.module);
+   e->engine.module = em;
+   evas_module_ref(em);
+   /* get the engine info struct */
+   if (e->engine.func->info) e->engine.info = e->engine.func->info(e);
+   return;
 }
 
 /**
@@ -328,18 +325,19 @@ evas_engine_info_get(const Evas *e)
  *
  * @param   e    The pointer to the Evas Canvas
  * @param   info The pointer to the Engine Info to use
+ * @return  1 if no error occured, 0 otherwise
  * @ingroup Evas_Output_Method
  */
-EAPI void
+EAPI int
 evas_engine_info_set(Evas *e, Evas_Engine_Info *info)
 {
    MAGIC_CHECK(e, Evas, MAGIC_EVAS);
-   return;
+   return 0;
    MAGIC_CHECK_END();
-   if (!info) return;
-   if (info != e->engine.info) return;
-   if (info->magic != e->engine.info_magic) return;
-   e->engine.func->setup(e, info);
+   if (!info) return 0;
+   if (info != e->engine.info) return 0;
+   if (info->magic != e->engine.info_magic) return 0;
+   return e->engine.func->setup(e, info);
 }
 
 /**
@@ -667,25 +665,14 @@ evas_coord_world_y_to_screen(const Evas *e, Evas_Coord y)
 EAPI int
 evas_render_method_lookup(const char *name)
 {
-   static int i = 1;
    Evas_Module *em;
-   Evas_Module_Engine *eem;
-   
+
    if (!name) return RENDER_METHOD_INVALID;
    /* search on the engines list for the name */
    em = evas_module_find_type(EVAS_MODULE_TYPE_ENGINE, name);
-   
    if (!em) return RENDER_METHOD_INVALID;
-   
-   eem = (Evas_Module_Engine *)em->data;
-   if (!eem)
-     {
-	eem = malloc(sizeof(Evas_Module_Engine));
-	em->data = eem;
-	eem->id = i;
-	i++;
-     }
-   return eem->id;
+
+   return em->id_engine;
 }
 
 /**
@@ -704,7 +691,8 @@ evas_render_method_lookup(const char *name)
  *
  * Example:
  * @code
- * Evas_List *engine_list, *l;
+ * Eina_List *engine_list, *l;
+ * char *engine_name;
  *
  * engine_list = evas_render_method_list();
  * if (!engine_list)
@@ -713,75 +701,70 @@ evas_render_method_lookup(const char *name)
  *     exit(-1);
  *   }
  * printf("Availible Evas Engines:\n");
- * for (l = engine_list; l; l = l->next)
- *   {
- *     char *engine_name;
- *
- *     engine_name = l->data;
+ * EINA_LIST_FOREACH(engine_list, l, engine_name)
  *     printf("%s\n", engine_name);
- *   }
  * evas_render_method_list_free(engine_list);
  * @endcode
  */
-EAPI Evas_List *
+EAPI Eina_List *
 evas_render_method_list(void)
 {
-   Evas_List *methods = NULL;
+   Eina_List *methods = NULL;
 
    /* FIXME: get from modules - this is currently coded-in */
+#ifdef BUILD_ENGINE_SOFTWARE_GDI
+   methods = eina_list_append(methods, "software_gdi");
+#endif
 #ifdef BUILD_ENGINE_SOFTWARE_DDRAW
-   methods = evas_list_append(methods, strdup("software_ddraw"));
+   methods = eina_list_append(methods, "software_ddraw");
 #endif
 #ifdef BUILD_ENGINE_SOFTWARE_16_DDRAW
-   methods = evas_list_append(methods, strdup("software_16_ddraw"));
+   methods = eina_list_append(methods, "software_16_ddraw");
 #endif
 #ifdef BUILD_ENGINE_DIRECT3D
-   methods = evas_list_append(methods, strdup("direct3d"));
+   methods = eina_list_append(methods, "direct3d");
 #endif
 #ifdef BUILD_ENGINE_SOFTWARE_16_WINCE
-   methods = evas_list_append(methods, strdup("software_16_wince"));
+   methods = eina_list_append(methods, "software_16_wince");
 #endif
 #ifdef BUILD_ENGINE_SOFTWARE_X11
-   methods = evas_list_append(methods, strdup("software_x11"));
+   methods = eina_list_append(methods, "software_x11");
 #endif
 #ifdef BUILD_ENGINE_XRENDER_X11
-   methods = evas_list_append(methods, strdup("xrender_x11"));
-#endif
-#ifdef BUILD_ENGINE_SOFTWARE_XCB
-   methods = evas_list_append(methods, strdup("software_xcb"));
+   methods = eina_list_append(methods, "xrender_x11");
 #endif
 #ifdef BUILD_ENGINE_XRENDER_XCB
-   methods = evas_list_append(methods, strdup("xrender_xcb"));
+   methods = eina_list_append(methods, "xrender_xcb");
 #endif
 #ifdef BUILD_ENGINE_SOFTWARE_16_X11
-   methods = evas_list_append(methods, strdup("software_16_x11"));
+   methods = eina_list_append(methods, "software_16_x11");
 #endif
 #ifdef BUILD_ENGINE_GL_X11
-   methods = evas_list_append(methods, strdup("gl_x11"));
+   methods = eina_list_append(methods, "gl_x11");
 #endif
 #ifdef BUILD_ENGINE_GL_GLEW
-   methods = evas_list_append(methods, strdup("gl_glew"));
+   methods = eina_list_append(methods, "gl_glew");
 #endif
 #ifdef BUILD_ENGINE_CAIRO_X11
-   methods = evas_list_append(methods, strdup("cairo_x11"));
+   methods = eina_list_append(methods, "cairo_x11");
 #endif
 #ifdef BUILD_ENGINE_DIRECTFB
-   methods = evas_list_append(methods, strdup("directfb"));
+   methods = eina_list_append(methods, "directfb");
 #endif
 #ifdef BUILD_ENGINE_FB
-   methods = evas_list_append(methods, strdup("fb"));
+   methods = eina_list_append(methods, "fb");
 #endif
 #ifdef BUILD_ENGINE_BUFFER
-   methods = evas_list_append(methods, strdup("buffer"));
+   methods = eina_list_append(methods, "buffer");
 #endif
 #ifdef BUILD_ENGINE_SOFTWARE_WIN32_GDI
-   methods = evas_list_append(methods, strdup("software_win32_gdi"));
+   methods = eina_list_append(methods, "software_win32_gdi");
 #endif
 #ifdef BUILD_ENGINE_SOFTWARE_QTOPIA
-   methods = evas_list_append(methods, strdup("software_qtopia"));
+   methods = eina_list_append(methods, "software_qtopia");
 #endif
-#ifdef BUILD_ENGINE_SDL
-   methods = evas_list_append(methods, strdup("software_sdl"));
+#ifdef BUILD_ENGINE_SOFTWARE_SDL
+   methods = eina_list_append(methods, "software_sdl");
 #endif
 
    return methods;
@@ -790,7 +773,7 @@ evas_render_method_list(void)
 /**
  * This function should be called to free a list of engine names
  *
- * @param list The Evas_List base pointer for the engine list to be freed
+ * @param list The Eina_List base pointer for the engine list to be freed
  * @ingroup Evas_Output_Method
  *
  * When this function is called it will free the engine list passed in as
@@ -799,7 +782,8 @@ evas_render_method_list(void)
  *
  * Example:
  * @code
- * Evas_List *engine_list, *l;
+ * Eina_List *engine_list, *l;
+ * char *engine_name;
  *
  * engine_list = evas_render_method_list();
  * if (!engine_list)
@@ -808,24 +792,15 @@ evas_render_method_list(void)
  *     exit(-1);
  *   }
  * printf("Availible Evas Engines:\n");
- * for (l = engine_list; l; l = l->next)
- *   {
- *     char *engine_name;
- *
- *     engine_name = l->data;
+ * EINA_LIST_FOREACH(engine_list, l, engine_name)
  *     printf("%s\n", engine_name);
- *   }
  * evas_render_method_list_free(engine_list);
  * @endcode
  */
 EAPI void
-evas_render_method_list_free(Evas_List *list)
+evas_render_method_list_free(Eina_List *list)
 {
-   while (list)
-     {
-	free(list->data);
-	list = evas_list_remove(list, list->data);
-     }
+   eina_list_free(list);
 }
 
 /**
@@ -974,7 +949,7 @@ evas_pointer_button_down_mask_get(const Evas *e)
  * else printf("Mouse is out!\n");
  * @endcode
  */
-EAPI Evas_Bool
+EAPI Eina_Bool
 evas_pointer_inside_get(const Evas *e)
 {
    MAGIC_CHECK(e, Evas, MAGIC_EVAS);
