@@ -2,16 +2,14 @@
 #include "evas_private.h"
 
 /**
- * @defgroup Evas_Object_Name_Group Object Name Function
- *
- * Functions that retrieve and set the name of an evas object.
+ * @addtogroup Evas_Object_Group
+ * @{
  */
 
 /**
  * Sets the name of the given evas object to the given name.
  * @param   obj  The given object.
  * @param   name The given name.
- * @ingroup Evas_Object_Name_Group
  */
 EAPI void
 evas_object_name_set(Evas_Object *obj, const char *name)
@@ -21,14 +19,14 @@ evas_object_name_set(Evas_Object *obj, const char *name)
    MAGIC_CHECK_END();
    if (obj->name)
      {
-	obj->layer->evas->name_hash = evas_hash_del(obj->layer->evas->name_hash, obj->name, obj);
+       eina_hash_del(obj->layer->evas->name_hash, obj->name, obj);
 	free(obj->name);
      }
    if (!name) obj->name = NULL;
    else
      {
 	obj->name = strdup(name);
-	obj->layer->evas->name_hash = evas_hash_add(obj->layer->evas->name_hash, obj->name, obj);
+	eina_hash_add(obj->layer->evas->name_hash, obj->name, obj);
      }
 }
 
@@ -37,7 +35,6 @@ evas_object_name_set(Evas_Object *obj, const char *name)
  * @param   obj The given object.
  * @return  The name of the object.  @c NULL if no name has been given
  *          to the object.
- * @ingroup Evas_Object_Name_Group
  */
 EAPI const char *
 evas_object_name_get(const Evas_Object *obj)
@@ -54,7 +51,6 @@ evas_object_name_get(const Evas_Object *obj)
  * @param   name The given name.
  * @return  If successful, the evas object with the given name.  Otherwise,
  *          @c NULL.
- * @ingroup Evas_Object_Name_Group
  */
 EAPI Evas_Object *
 evas_object_name_find(const Evas *e, const char *name)
@@ -63,5 +59,9 @@ evas_object_name_find(const Evas *e, const char *name)
    return NULL;
    MAGIC_CHECK_END();
    if (!name) return NULL;
-   return (Evas_Object *)evas_hash_find(e->name_hash, name);
+   return (Evas_Object *)eina_hash_find(e->name_hash, name);
 }
+
+/**
+ * @}
+ */
