@@ -13,12 +13,24 @@
  */
 //#define FORWARD_NOOP_RESIZES_TO_SMART_OBJS
 
-static Evas_Object_List *
+/* Similar to FORWARD_NOOP_*, this will allow no-operations (those calls that
+ * have values exactly like current state) to call EVAS_CALLBACK_*.
+ *
+ * For some unknown reason this was the default behavior so it is left as
+ * a compile-time option, but will be deprecated and removed soon as it can
+ * potentially lead to execution of unnecessary code.
+ * by Gustavo, February 5th, 2009.
+ * XXX: remove-me before e17 release!
+ */
+//#define CALLBACK_NOOP
+
+
+static Eina_Inlist *
 get_layer_objects_last(Evas_Layer *l)
 {
    if( !l || !l->objects ) return NULL;
 
-   return ((Evas_Object_List *)(l->objects))->last;
+   return (EINA_INLIST_GET(l->objects))->last;
 }
 
 /* evas internal stuff */
@@ -49,15 +61,8 @@ evas_object_free(Evas_Object *obj, int clean_layer)
    obj->func->free(obj);
    if (!was_smart_child) evas_object_release(obj, clean_layer);
    if (obj->clip.clipees)
-     evas_list_free(obj->clip.clipees);
-   while (obj->clip.changes)
-     {
-	Evas_Rectangle *r;
-
-	r = (Evas_Rectangle *)obj->clip.changes->data;
-	obj->clip.changes = evas_list_remove(obj->clip.changes, r);
-	free(r);
-     }
+     eina_list_free(obj->clip.clipees);
+   evas_object_clip_changes_clean(obj);
    evas_object_event_callback_all_del(obj);
    evas_object_event_callback_cleanup(obj);
    while (obj->data.elements)
@@ -65,7 +70,7 @@ evas_object_free(Evas_Object *obj, int clean_layer)
 	Evas_Data_Node *node;
 
 	node = obj->data.elements->data;
-	obj->data.elements = evas_list_remove(obj->data.elements, node);
+	obj->data.elements = eina_list_remove(obj->data.elements, node);
 	free(node);
      }
    obj->magic = 0;
@@ -76,19 +81,20 @@ evas_object_free(Evas_Object *obj, int clean_layer)
 void
 evas_object_change(Evas_Object *obj)
 {
-   Evas_List *l;
+   Eina_List *l;
+   Evas_Object *data;
 
    obj->layer->evas->changed = 1;
    if (obj->changed) return;
    evas_render_object_recalc(obj);
    /* set changed flag on all objects this one clips too */
-   for (l = obj->clip.clipees; l; l = l->next)
-     evas_object_change((Evas_Object *)l->data);
+   EINA_LIST_FOREACH(obj->clip.clipees, l, data)
+     evas_object_change(data);
    if (obj->smart.parent) evas_object_change(obj->smart.parent);
 }
 
 void
-evas_object_render_pre_visible_change(Evas_Rectangles *rects, Evas_Object *obj, int is_v, int was_v)
+evas_object_render_pre_visible_change(Eina_Array *rects, Evas_Object *obj, int is_v, int was_v)
 {
    if (obj->smart.smart) return ;
    if (is_v == was_v) return ;
@@ -111,7 +117,7 @@ evas_object_render_pre_visible_change(Evas_Rectangles *rects, Evas_Object *obj,
 }
 
 void
-evas_object_render_pre_clipper_change(Evas_Rectangles *rects, Evas_Object *obj)
+evas_object_render_pre_clipper_change(Eina_Array *rects, Evas_Object *obj)
 {
    if (obj->smart.smart) return ;
    if (obj->cur.clipper == obj->prev.clipper) return ;
@@ -163,7 +169,7 @@ evas_object_render_pre_clipper_change(Evas_Rectangles *rects, Evas_Object *obj)
 }
 
 void
-evas_object_render_pre_prev_cur_add(Evas_Rectangles *rects, Evas_Object *obj)
+evas_object_render_pre_prev_cur_add(Eina_Array *rects, Evas_Object *obj)
 {
    evas_add_rect(rects,
 		 obj->cur.geometry.x,
@@ -186,12 +192,23 @@ evas_object_render_pre_prev_cur_add(Evas_Rectangles *rects, Evas_Object *obj)
 }
 
 void
-evas_object_render_pre_effect_updates(Evas_Rectangles *rects, Evas_Object *obj, int is_v, int was_v)
+evas_object_clip_changes_clean(Evas_Object *obj)
 {
-   Evas_Rectangle *r;
+   Eina_Rectangle *r;
+
+   EINA_LIST_FREE(obj->clip.changes, r)
+     eina_rectangle_free(r);
+}
+
+
+void
+evas_object_render_pre_effect_updates(Eina_Array *rects, Evas_Object *obj, int is_v, int was_v)
+{
+   Eina_Rectangle *r;
    Evas_Object *clipper;
-   Evas_List *l;
+   Eina_List *l;
    unsigned int i;
+   Eina_Array_Iterator it;
    int x, y, w, h;
 
    if (obj->smart.smart) goto end;
@@ -199,13 +216,13 @@ evas_object_render_pre_effect_updates(Evas_Rectangles *rects, Evas_Object *obj,
    was_v = 0;
    if (!obj->clip.clipees)
      {
-	for (i = 0; i < rects->count; ++i)
+	EINA_ARRAY_ITER_NEXT(rects, i, r, it)
 	  {
 	     /* get updates and clip to current clip */
-	     x = rects->array[i].x;
-	     y = rects->array[i].y;
-	     w = rects->array[i].w;
-	     h = rects->array[i].h;
+	     x = r->x;
+	     y = r->y;
+	     w = r->w;
+	     h = r->h;
 	     RECTS_CLIP_TO_RECT(x, y, w, h,
 				obj->cur.cache.clip.x,
 				obj->cur.cache.clip.y,
@@ -215,10 +232,10 @@ evas_object_render_pre_effect_updates(Evas_Rectangles *rects, Evas_Object *obj,
 	       obj->layer->evas->engine.func->output_redraws_rect_add(obj->layer->evas->engine.data.output,
 								      x, y, w, h);
 	     /* get updates and clip to previous clip */
-	     x = rects->array[i].x;
-	     y = rects->array[i].y;
-	     w = rects->array[i].w;
-	     h = rects->array[i].h;
+	     x = r->x;
+	     y = r->y;
+	     w = r->w;
+	     h = r->h;
 	     RECTS_CLIP_TO_RECT(x, y, w, h,
 				obj->prev.cache.clip.x,
 				obj->prev.cache.clip.y,
@@ -234,9 +251,8 @@ evas_object_render_pre_effect_updates(Evas_Rectangles *rects, Evas_Object *obj,
 	     clipper = obj->cur.clipper;
 	     while (clipper)
 	       {
-		  for (l = clipper->clip.changes; l; l = l->next)
+		  EINA_LIST_FOREACH(clipper->clip.changes, l, r)
 		    {
-		       r = (Evas_Rectangle *)(l->data);
 		       /* get updates and clip to current clip */
 		       x = r->x; y = r->y; w = r->w; h = r->h;
 		       RECTS_CLIP_TO_RECT(x, y, w, h,
@@ -264,26 +280,16 @@ evas_object_render_pre_effect_updates(Evas_Rectangles *rects, Evas_Object *obj,
      }
    else
      {
-	while (obj->clip.changes)
-	  {
-	     free(obj->clip.changes->data);
-	     obj->clip.changes = evas_list_remove(obj->clip.changes, obj->clip.changes->data);
-	  }
-	for (i = 0; i < rects->count; ++i)
-	  {
-	     r = malloc(sizeof(Evas_Rectangle));
-	     if (!r) goto end;
-
-	     *r = rects->array[i];
-	     obj->clip.changes = evas_list_append(obj->clip.changes, r);
-	  }
+	evas_object_clip_changes_clean(obj);
+	EINA_ARRAY_ITER_NEXT(rects, i, r, it)
+	  obj->clip.changes = eina_list_append(obj->clip.changes, r);
+	eina_array_clean(rects);
      }
 
  end:
-   free(rects->array);
-   rects->array = NULL;
-   rects->count = 0;
-   rects->total = 0;
+   EINA_ARRAY_ITER_NEXT(rects, i, r, it)
+     eina_rectangle_free(r);
+   eina_array_clean(rects);
 }
 
 int
@@ -300,21 +306,6 @@ evas_object_was_in_output_rect(Evas_Object *obj, int x, int y, int w, int h)
    return 0;
 }
 
-int
-evas_object_was_visible(Evas_Object *obj)
-{
-   if (obj->smart.smart) return 0;
-   if ((obj->prev.visible) &&
-       (obj->prev.cache.clip.visible) &&
-       (obj->prev.cache.clip.a > 0))
-     {
-	if (obj->func->was_visible)
-	  return obj->func->was_visible(obj);
-	return 1;
-     }
-   return 0;
-}
-
 int
 evas_object_was_opaque(Evas_Object *obj)
 {
@@ -425,7 +416,9 @@ evas_object_move(Evas_Object *obj, Evas_Coord x, Evas_Coord y)
    if ((obj->cur.geometry.x == x) &&
        (obj->cur.geometry.y == y))
      {
+#ifdef CALLBACK_NOOP
 	evas_object_inform_call_move(obj);
+#endif
 	return;
      }
 #ifndef FORWARD_NOOP_MOVES_TO_SMART_OBJS
@@ -498,7 +491,9 @@ evas_object_resize(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
    if ((obj->cur.geometry.w == w) &&
        (obj->cur.geometry.h == h))
      {
+#ifdef CALLBACK_NOOP
 	evas_object_inform_call_resize(obj);
+#endif
 	return;
      }
 #ifndef FORWARD_NOOP_RESIZES_TO_SMART_OBJS
@@ -580,11 +575,22 @@ evas_object_geometry_get(const Evas_Object *obj, Evas_Coord *x, Evas_Coord *y, E
 }
 
 /**
- * @defgroup Evas_Object_Size_Hints_Group Generic Object Size Hints Functions
- *
- * Functions that deals with hints about object size.
+ * @addtogroup Evas_Object_Group
+ * @{
  */
 
+static void
+_evas_object_size_hint_alloc(Evas_Object *obj)
+{
+   if (obj->size_hints) return;
+   
+   obj->size_hints = calloc(1, sizeof(Evas_Size_Hints));
+   obj->size_hints->max.w = -1;
+   obj->size_hints->max.h = -1;
+   obj->size_hints->align.x = 0.5;
+   obj->size_hints->align.y = 0.5;
+}
+
 /**
  * Retrieves the size hint for the minimum size.
  *
@@ -597,7 +603,6 @@ evas_object_geometry_get(const Evas_Object *obj, Evas_Coord *x, Evas_Coord *y, E
  * @param obj The given evas object.
  * @param   w Pointer to an integer in which to store the minimum width.
  * @param   h Pointer to an integer in which to store the minimum height.
- * @ingroup Evas_Object_Size_Hints_Group
  */
 EAPI void
 evas_object_size_hint_min_get(const Evas_Object *obj, Evas_Coord *w, Evas_Coord *h)
@@ -621,10 +626,11 @@ evas_object_size_hint_min_get(const Evas_Object *obj, Evas_Coord *w, Evas_Coord
  * This is not a size enforcement in any way, it's just a hint that should
  * be used whenever appropriate.
  *
+ * Value 0 is considered unset.
+ *
  * @param obj The given evas object.
  * @param   w Integer to use as the minimum width hint.
  * @param   h Integer to use as the minimum height hint.
- * @ingroup Evas_Object_Size_Hints_Group
  */
 EAPI void
 evas_object_size_hint_min_set(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
@@ -634,9 +640,8 @@ evas_object_size_hint_min_set(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
    MAGIC_CHECK_END();
    if (obj->delete_me)
      return;
-   if (!obj->size_hints)
-     obj->size_hints = calloc(1, sizeof(Evas_Size_Hints));
-
+   _evas_object_size_hint_alloc(obj);
+   if ((obj->size_hints->min.w == w) && (obj->size_hints->min.h == h)) return;
    obj->size_hints->min.w = w;
    obj->size_hints->min.h = h;
 
@@ -655,18 +660,17 @@ evas_object_size_hint_min_set(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
  * @param obj The given evas object.
  * @param   w Pointer to an integer in which to store the maximum width.
  * @param   h Pointer to an integer in which to store the maximum height.
- * @ingroup Evas_Object_Size_Hints_Group
  */
 EAPI void
 evas_object_size_hint_max_get(const Evas_Object *obj, Evas_Coord *w, Evas_Coord *h)
 {
    MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
-   if (w) *w = 0; if (h) *h = 0;
+   if (w) *w = -1; if (h) *h = -1;
    return;
    MAGIC_CHECK_END();
    if ((!obj->size_hints) || obj->delete_me)
      {
-	if (w) *w = 0; if (h) *h = 0;
+	if (w) *w = -1; if (h) *h = -1;
 	return;
      }
    if (w) *w = obj->size_hints->max.w;
@@ -679,10 +683,11 @@ evas_object_size_hint_max_get(const Evas_Object *obj, Evas_Coord *w, Evas_Coord
  * This is not a size enforcement in any way, it's just a hint that should
  * be used whenever appropriate.
  *
+ * Value -1 is considered unset.
+ *
  * @param obj The given evas object.
  * @param   w Integer to use as the maximum width hint.
  * @param   h Integer to use as the maximum height hint.
- * @ingroup Evas_Object_Size_Hints_Group
  */
 EAPI void
 evas_object_size_hint_max_set(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
@@ -692,9 +697,8 @@ evas_object_size_hint_max_set(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
    MAGIC_CHECK_END();
    if (obj->delete_me)
      return;
-   if (!obj->size_hints)
-     obj->size_hints = calloc(1, sizeof(Evas_Size_Hints));
-
+   _evas_object_size_hint_alloc(obj);
+   if ((obj->size_hints->max.w == w) && (obj->size_hints->max.h == h)) return;
    obj->size_hints->max.w = w;
    obj->size_hints->max.h = h;
 
@@ -713,7 +717,6 @@ evas_object_size_hint_max_set(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
  * @param obj The given evas object.
  * @param   w Pointer to an integer in which to store the requested width.
  * @param   h Pointer to an integer in which to store the requested height.
- * @ingroup Evas_Object_Size_Hints_Group
  */
 EAPI void
 evas_object_size_hint_request_get(const Evas_Object *obj, Evas_Coord *w, Evas_Coord *h)
@@ -737,10 +740,11 @@ evas_object_size_hint_request_get(const Evas_Object *obj, Evas_Coord *w, Evas_Co
  * This is not a size enforcement in any way, it's just a hint that should
  * be used whenever appropriate.
  *
+ * Value 0 is considered unset.
+ *
  * @param obj The given evas object.
  * @param   w Integer to use as the preferred width hint.
  * @param   h Integer to use as the preferred height hint.
- * @ingroup Evas_Object_Size_Hints_Group
  */
 EAPI void
 evas_object_size_hint_request_set(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
@@ -750,9 +754,8 @@ evas_object_size_hint_request_set(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
    MAGIC_CHECK_END();
    if (obj->delete_me)
      return;
-   if (!obj->size_hints)
-     obj->size_hints = calloc(1, sizeof(Evas_Size_Hints));
-
+   _evas_object_size_hint_alloc(obj);
+   if ((obj->size_hints->request.w == w) && (obj->size_hints->request.h == h)) return;
    obj->size_hints->request.w = w;
    obj->size_hints->request.h = h;
 
@@ -772,7 +775,6 @@ evas_object_size_hint_request_set(Evas_Object *obj, Evas_Coord w, Evas_Coord h)
  * @param aspect Returns the hint on how size should be calculated.
  * @param      w Pointer to an integer in which to store the aspect width.
  * @param      h Pointer to an integer in which to store the aspect height.
- * @ingroup Evas_Object_Size_Hints_Group
  */
 EAPI void
 evas_object_size_hint_aspect_get(const Evas_Object *obj, Evas_Aspect_Control *aspect, Evas_Coord *w, Evas_Coord *h)
@@ -803,7 +805,6 @@ evas_object_size_hint_aspect_get(const Evas_Object *obj, Evas_Aspect_Control *as
  * @param aspect Hint on how to calculate size.
  * @param      w Integer to use as aspect width hint.
  * @param      h Integer to use as aspect height hint.
- * @ingroup Evas_Object_Size_Hints_Group
  */
 EAPI void
 evas_object_size_hint_aspect_set(Evas_Object *obj, Evas_Aspect_Control aspect, Evas_Coord w, Evas_Coord h)
@@ -813,9 +814,8 @@ evas_object_size_hint_aspect_set(Evas_Object *obj, Evas_Aspect_Control aspect, E
    MAGIC_CHECK_END();
    if (obj->delete_me)
      return;
-   if (!obj->size_hints)
-     obj->size_hints = calloc(1, sizeof(Evas_Size_Hints));
-
+   _evas_object_size_hint_alloc(obj);
+   if ((obj->size_hints->aspect.mode == aspect) && (obj->size_hints->aspect.size.w == w) && (obj->size_hints->aspect.size.h == h)) return;
    obj->size_hints->aspect.mode = aspect;
    obj->size_hints->aspect.size.w = w;
    obj->size_hints->aspect.size.h = h;
@@ -823,17 +823,198 @@ evas_object_size_hint_aspect_set(Evas_Object *obj, Evas_Aspect_Control aspect, E
    evas_object_inform_call_changed_size_hints(obj);
 }
 
+/**
+ * Retrieves the size align control hint.
+ *
+ * This is not a size enforcement in any way, it's just a hint that should
+ * be used whenever appropriate.
+ *
+ * Note that if any of @p x or @p y are @c NULL, the @c NULL
+ * parameters are ignored.
+ *
+ * @param    obj The given evas object.
+ * @param      x Pointer to a double in which to store the align x.
+ * @param      y Pointer to a double in which to store the align y.
+ */
+EAPI void
+evas_object_size_hint_align_get(const Evas_Object *obj, double *x, double *y)
+{
+   MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
+   if (x) *x = 0.5; if (y) *y = 0.5;
+   return;
+   MAGIC_CHECK_END();
+   if ((!obj->size_hints) || obj->delete_me)
+     {
+	if (x) *x = 0.5; if (y) *y = 0.5;
+	return;
+     }
+   if (x) *x = obj->size_hints->align.x;
+   if (y) *y = obj->size_hints->align.y;
+}
 
 /**
- * @defgroup Evas_Object_Visibility_Group Generic Object Visibility Functions
+ * Sets the size align control hint.
  *
- * Functions that deal with the visibility of evas objects.
+ * This is not a size enforcement in any way, it's just a hint that should
+ * be used whenever appropriate.
+ *
+ * Accepted values are in the 0.0 to 1.0 range, with the special value
+ * -1.0 used to specify "justify" or "fill" by some users. See
+ * documentation of possible users.
+ *
+ * @param    obj The given evas object.
+ * @param      x Double (0.0..1.0 or -1.0) to use as align x hint.
+ * @param      y Double (0.0..1.0 or -1.0) to use as align y hint.
+ */
+EAPI void
+evas_object_size_hint_align_set(Evas_Object *obj, double x, double y)
+{
+   MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
+   return;
+   MAGIC_CHECK_END();
+   if (obj->delete_me)
+     return;
+   _evas_object_size_hint_alloc(obj);
+   if ((obj->size_hints->align.x == x) && (obj->size_hints->align.y == y)) return;
+   obj->size_hints->align.x = x;
+   obj->size_hints->align.y = y;
+
+   evas_object_inform_call_changed_size_hints(obj);
+}
+
+/**
+ * Retrieves the size weight control hint.
+ *
+ * This is not a size enforcement in any way, it's just a hint that should
+ * be used whenever appropriate.
+ *
+ * Note that if any of @p x or @p y are @c NULL, the @c NULL
+ * parameters are ignored.
+ *
+ * Accepted values are zero or positive values. Some users might use
+ * this hint as a boolean, but some might consider it as a proportion,
+ * see documentation of possible users.
+ *
+ * @param    obj The given evas object.
+ * @param      x Pointer to a double in which to store the weight x.
+ * @param      y Pointer to a double in which to store the weight y.
+ */
+EAPI void
+evas_object_size_hint_weight_get(const Evas_Object *obj, double *x, double *y)
+{
+   MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
+   if (x) *x = 0.0; if (y) *y = 0.0;
+   return;
+   MAGIC_CHECK_END();
+   if ((!obj->size_hints) || obj->delete_me)
+     {
+	if (x) *x = 0.0; if (y) *y = 0.0;
+	return;
+     }
+   if (x) *x = obj->size_hints->weight.x;
+   if (y) *y = obj->size_hints->weight.y;
+}
+
+/**
+ * Sets the size weight control hint.
+ *
+ * This is not a size enforcement in any way, it's just a hint that should
+ * be used whenever appropriate.
+ *
+ * @param    obj The given evas object.
+ * @param      x Double (0.0-1.0) to use as weight x hint.
+ * @param      y Double (0.0-1.0) to use as weight y hint.
+ */
+EAPI void
+evas_object_size_hint_weight_set(Evas_Object *obj, double x, double y)
+{
+   MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
+   return;
+   MAGIC_CHECK_END();
+   if (obj->delete_me)
+     return;
+   _evas_object_size_hint_alloc(obj);
+   if ((obj->size_hints->weight.x == x) && (obj->size_hints->weight.y == y)) return;
+   obj->size_hints->weight.x = x;
+   obj->size_hints->weight.y = y;
+
+   evas_object_inform_call_changed_size_hints(obj);
+}
+
+/**
+ * Retrieves the size padding control hint.
+ *
+ * This is not a size enforcement in any way, it's just a hint that should
+ * be used whenever appropriate.
+ *
+ * Note that if any of @p l, @p r, @p t or @p b are @c NULL, the @c
+ * NULL parameters are ignored.
+ *
+ * @param    obj The given evas object.
+ * @param      l Pointer to an integer in which to store left padding.
+ * @param      r Pointer to an integer in which to store right padding.
+ * @param      t Pointer to an integer in which to store top padding.
+ * @param      b Pointer to an integer in which to store bottom padding.
+ */
+EAPI void
+evas_object_size_hint_padding_get(const Evas_Object *obj, Evas_Coord *l, Evas_Coord *r, Evas_Coord *t, Evas_Coord *b)
+{
+   MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
+   if (l) *l = 0; if (r) *r = 0;
+   if (t) *t = 0; if (b) *b = 0;
+   return;
+   MAGIC_CHECK_END();
+   if ((!obj->size_hints) || obj->delete_me)
+     {
+	if (l) *l = 0; if (r) *r = 0;
+	if (t) *t = 0; if (b) *b = 0;
+	return;
+     }
+   if (l) *l = obj->size_hints->padding.l;
+   if (r) *r = obj->size_hints->padding.r;
+   if (t) *t = obj->size_hints->padding.t;
+   if (b) *b = obj->size_hints->padding.b;
+}
+
+/**
+ * Sets the size padding control hint.
+ *
+ * This is not a size enforcement in any way, it's just a hint that should
+ * be used whenever appropriate.
+ *
+ * @param    obj The given evas object.
+ * @param      l Integer to specify left padding.
+ * @param      r Integer to specify right padding.
+ * @param      t Integer to specify top padding.
+ * @param      b Integer to specify bottom padding.
+ */
+EAPI void
+evas_object_size_hint_padding_set(Evas_Object *obj, Evas_Coord l, Evas_Coord r, Evas_Coord t, Evas_Coord b)
+{
+   MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
+   return;
+   MAGIC_CHECK_END();
+   if (obj->delete_me)
+     return;
+   _evas_object_size_hint_alloc(obj);
+   if ((obj->size_hints->padding.l == l) && (obj->size_hints->padding.r == r) && (obj->size_hints->padding.t == t) && (obj->size_hints->padding.b == b)) return;
+   obj->size_hints->padding.l = l;
+   obj->size_hints->padding.r = r;
+   obj->size_hints->padding.t = t;
+   obj->size_hints->padding.b = b;
+
+   evas_object_inform_call_changed_size_hints(obj);
+}
+
+
+/**
+ * @}
  */
 
 /**
  * Makes the given evas object visible.
  * @param   obj The given evas object.
- * @ingroup Evas_Object_Visibility_Group
+ * @ingroup Evas_Object_Group
  */
 EAPI void
 evas_object_show(Evas_Object *obj)
@@ -850,7 +1031,9 @@ evas_object_show(Evas_Object *obj)
      }
    if (obj->cur.visible)
      {
+#ifdef CALLBACK_NOOP
 	evas_object_inform_call_show(obj);
+#endif
 	return;
      }
    obj->cur.visible = 1;
@@ -880,7 +1063,7 @@ evas_object_show(Evas_Object *obj)
 /**
  * Makes the given evas object invisible.
  * @param   obj The given evas object.
- * @ingroup Evas_Object_Visibility_Group
+ * @ingroup Evas_Object_Group
  */
 EAPI void
 evas_object_hide(Evas_Object *obj)
@@ -897,7 +1080,9 @@ evas_object_hide(Evas_Object *obj)
      }
    if (!obj->cur.visible)
      {
+#ifdef CALLBACK_NOOP
 	evas_object_inform_call_hide(obj);
+#endif
 	return;
      }
    obj->cur.visible = 0;
@@ -924,32 +1109,32 @@ evas_object_hide(Evas_Object *obj)
 //		       if (obj->layer->evas->pointer.mouse_grabbed >= obj->mouse_grabbed)
 			 obj->layer->evas->pointer.mouse_grabbed -= obj->mouse_grabbed;
 		    }
-		    {
-		       if ((obj->mouse_in) || (obj->mouse_grabbed > 0))
-			 {
-			    obj->layer->evas->pointer.object.in = evas_list_remove(obj->layer->evas->pointer.object.in, obj);
-			 }
-		       obj->mouse_grabbed = 0;
-		       if (obj->layer->evas->events_frozen > 0)
-			 {
-			    obj->mouse_in = 0;
-			    return;
-			 }
-		       if (obj->mouse_in)
-			 {
-			    Evas_Event_Mouse_Out ev;
-			    
-			    obj->mouse_in = 0;
-			    ev.buttons = obj->layer->evas->pointer.button;
-			    ev.output.x = obj->layer->evas->pointer.x;
-			    ev.output.y = obj->layer->evas->pointer.y;
-			    ev.canvas.x = obj->layer->evas->pointer.x;
-			    ev.canvas.y = obj->layer->evas->pointer.y;
-			    ev.data = NULL;
-			    ev.modifiers = &(obj->layer->evas->modifiers);
-			    ev.locks = &(obj->layer->evas->locks);
-			    evas_object_event_callback_call(obj, EVAS_CALLBACK_MOUSE_OUT, &ev);
-			 }
+                  if ((obj->mouse_in) || (obj->mouse_grabbed > 0))
+                    {
+                       obj->layer->evas->pointer.object.in = eina_list_remove(obj->layer->evas->pointer.object.in, obj);
+                    }
+                  obj->mouse_grabbed = 0;
+                  if (obj->layer->evas->events_frozen > 0)
+                    {
+                       obj->mouse_in = 0;
+                       return;
+                    }
+                  if (obj->mouse_in)
+                    {
+                       Evas_Event_Mouse_Out ev;
+                       
+                       obj->mouse_in = 0;
+                       ev.buttons = obj->layer->evas->pointer.button;
+                       ev.output.x = obj->layer->evas->pointer.x;
+                       ev.output.y = obj->layer->evas->pointer.y;
+                       ev.canvas.x = obj->layer->evas->pointer.x;
+                       ev.canvas.y = obj->layer->evas->pointer.y;
+                       ev.data = NULL;
+                       ev.modifiers = &(obj->layer->evas->modifiers);
+                       ev.locks = &(obj->layer->evas->locks);
+		       ev.timestamp = obj->layer->evas->last_timestamp;
+		       ev.event_flags = EVAS_EVENT_FLAG_NONE;
+                       evas_object_event_callback_call(obj, EVAS_CALLBACK_MOUSE_OUT, &ev);
 		    }
 	       }
 	  }
@@ -957,7 +1142,7 @@ evas_object_hide(Evas_Object *obj)
    else
      {
 	if ((obj->mouse_in) || (obj->mouse_grabbed > 0))
-	  obj->layer->evas->pointer.object.in = evas_list_remove(obj->layer->evas->pointer.object.in, obj);
+	  obj->layer->evas->pointer.object.in = eina_list_remove(obj->layer->evas->pointer.object.in, obj);
 	obj->mouse_grabbed = 0;
 	obj->mouse_in = 0;
      }
@@ -968,9 +1153,9 @@ evas_object_hide(Evas_Object *obj)
  * Retrieves whether or not the given evas object is visible.
  * @param   obj The given evas object.
  * @return  @c 1 if the object is visible.  @c 0 otherwise.
- * @ingroup Evas_Object_Visibility_Group
+ * @ingroup Evas_Object_Group
  */
-EAPI Evas_Bool
+EAPI Eina_Bool
 evas_object_visible_get(const Evas_Object *obj)
 {
    MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
@@ -1013,6 +1198,7 @@ evas_object_color_set(Evas_Object *obj, int r, int g, int b, int a)
    obj->cur.color.r = r;
    obj->cur.color.g = g;
    obj->cur.color.b = b;
+   evas_object_clip_dirty(obj);
    if ((obj->cur.color.a == 0) && (a == 0)) return;
    obj->cur.color.a = a;
    evas_object_change(obj);
@@ -1060,7 +1246,7 @@ evas_object_color_get(const Evas_Object *obj, int *r, int *g, int *b, int *a)
  * @ingroup Evas_Object_Group
  */
 EAPI void
-evas_object_anti_alias_set(Evas_Object *obj, Evas_Bool anti_alias)
+evas_object_anti_alias_set(Evas_Object *obj, Eina_Bool anti_alias)
 {
    MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
    return;
@@ -1079,7 +1265,7 @@ evas_object_anti_alias_set(Evas_Object *obj, Evas_Bool anti_alias)
  * @return  @c 1 if the object is to be anti_aliased.  @c 0 otherwise.
  * @ingroup Evas_Object_Group
  */
-EAPI Evas_Bool
+EAPI Eina_Bool
 evas_object_anti_alias_get(const Evas_Object *obj)
 {
    MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
@@ -1106,6 +1292,7 @@ evas_object_scale_set(Evas_Object *obj, double scale)
      return;
    obj->cur.scale = scale;
    evas_object_change(obj);
+   if (obj->func->scale_update) obj->func->scale_update(obj);
 }
 
 
@@ -1214,22 +1401,19 @@ evas_object_evas_get(const Evas_Object *obj)
 }
 
 /**
- * @defgroup Evas_Object_Finders Object Finder Functions
- *
- * Functions that determine what evas objects are at a given location
- * or within a given region of an evas.
+ * @addtogroup Evas_Object_Group
+ * @{
  */
 
 /**
  * To be documented.
  *
  * FIXME: To be fixed.
- * @ingroup Evas_Object_Finders
  */
 EAPI Evas_Object *
-evas_object_top_at_xy_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Bool include_pass_events_objects, Evas_Bool include_hidden_objects)
+evas_object_top_at_xy_get(const Evas *e, Evas_Coord x, Evas_Coord y, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects)
 {
-   Evas_Object_List *l;
+   Evas_Layer *lay;
    int xx, yy;
 
    MAGIC_CHECK(e, Evas, MAGIC_EVAS);
@@ -1239,17 +1423,12 @@ evas_object_top_at_xy_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Bool i
    yy = y;
 ////   xx = evas_coord_world_x_to_screen(e, x);
 ////   yy = evas_coord_world_y_to_screen(e, y);
-   for (l = ((Evas_Object_List *)(e->layers))->last; l; l = l->prev)
+   EINA_INLIST_REVERSE_FOREACH((EINA_INLIST_GET(e->layers)), lay)
      {
-	Evas_Object_List *l2;
-	Evas_Layer *lay;
+	Evas_Object *obj;
 
-	lay = (Evas_Layer *)l;
-	for (l2 = get_layer_objects_last(lay); l2; l2 = l2->prev)
+	EINA_INLIST_REVERSE_FOREACH(get_layer_objects_last(lay), obj)
 	  {
-	     Evas_Object *obj;
-
-	     obj = (Evas_Object *)l2;
 	     if (obj->delete_me) continue;
 	     if ((!include_pass_events_objects) && (evas_event_passes_through(obj))) continue;
 	     if ((!include_hidden_objects) && (!obj->cur.visible)) continue;
@@ -1266,7 +1445,6 @@ evas_object_top_at_xy_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Bool i
  * To be documented.
  *
  * FIXME: To be fixed.
- * @ingroup Evas_Object_Finders
  */
 EAPI Evas_Object *
 evas_object_top_at_pointer_get(const Evas *e)
@@ -1279,12 +1457,11 @@ evas_object_top_at_pointer_get(const Evas *e)
  * To be documented.
  *
  * FIXME: To be fixed.
- * @ingroup Evas_Object_Finders
  */
 EAPI Evas_Object *
-evas_object_top_in_rectangle_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h, Evas_Bool include_pass_events_objects, Evas_Bool include_hidden_objects)
+evas_object_top_in_rectangle_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects)
 {
-   Evas_Object_List *l;
+   Evas_Layer *lay;
    int xx, yy, ww, hh;
 
    MAGIC_CHECK(e, Evas, MAGIC_EVAS);
@@ -1300,17 +1477,12 @@ evas_object_top_in_rectangle_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas
 ////   hh = evas_coord_world_y_to_screen(e, h);
    if (ww < 1) ww = 1;
    if (hh < 1) hh = 1;
-   for (l = ((Evas_Object_List *)(e->layers))->last; l; l = l->prev)
+   EINA_INLIST_REVERSE_FOREACH((EINA_INLIST_GET(e->layers)), lay)
      {
-	Evas_Object_List *l2;
-	Evas_Layer *lay;
+	Evas_Object *obj;
 
-	lay = (Evas_Layer *)l;
-	for (l2 = get_layer_objects_last(lay); l2; l2 = l2->prev)
+	EINA_INLIST_REVERSE_FOREACH(get_layer_objects_last(lay), obj)
 	  {
-	     Evas_Object *obj;
-
-	     obj = (Evas_Object *)l2;
 	     if (obj->delete_me) continue;
 	     if ((!include_pass_events_objects) && (evas_event_passes_through(obj))) continue;
 	     if ((!include_hidden_objects) && (!obj->cur.visible)) continue;
@@ -1327,13 +1499,12 @@ evas_object_top_in_rectangle_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas
  * To be documented.
  *
  * FIXME: To be fixed.
- * @ingroup Evas_Object_Finders
  */
-EAPI Evas_List *
-evas_objects_at_xy_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Bool include_pass_events_objects, Evas_Bool include_hidden_objects)
+EAPI Eina_List *
+evas_objects_at_xy_get(const Evas *e, Evas_Coord x, Evas_Coord y, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects)
 {
-   Evas_List *in = NULL;
-   Evas_Object_List *l;
+   Eina_List *in = NULL;
+   Evas_Layer *lay;
    int xx, yy;
 
    MAGIC_CHECK(e, Evas, MAGIC_EVAS);
@@ -1343,24 +1514,19 @@ evas_objects_at_xy_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Bool incl
    yy = y;
 ////   xx = evas_coord_world_x_to_screen(e, x);
 ////   yy = evas_coord_world_y_to_screen(e, y);
-   for (l = ((Evas_Object_List *)(e->layers))->last; l; l = l->prev)
+   EINA_INLIST_REVERSE_FOREACH((EINA_INLIST_GET(e->layers)), lay)
      {
-	Evas_Object_List *l2;
-	Evas_Layer *lay;
+	Evas_Object *obj;
 
-	lay = (Evas_Layer *)l;
-	for (l2 = get_layer_objects_last(lay); l2; l2 = l2->prev)
+	EINA_INLIST_REVERSE_FOREACH(get_layer_objects_last(lay), obj)
 	  {
-	     Evas_Object *obj;
-
-	     obj = (Evas_Object *)l2;
 	     if (obj->delete_me) continue;
 	     if ((!include_pass_events_objects) && (evas_event_passes_through(obj))) continue;
 	     if ((!include_hidden_objects) && (!obj->cur.visible)) continue;
 	     evas_object_clip_recalc(obj);
 	     if ((evas_object_is_in_output_rect(obj, xx, yy, 1, 1)) &&
 		 (!obj->clip.clipees))
-	       in = evas_list_prepend(in, obj);
+	       in = eina_list_prepend(in, obj);
 	  }
      }
    return in;
@@ -1370,13 +1536,12 @@ evas_objects_at_xy_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Bool incl
  * To be documented.
  *
  * FIXME: To be fixed.
- * @ingroup Evas_Object_Finders
  */
-EAPI Evas_List *
-evas_objects_in_rectangle_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h, Evas_Bool include_pass_events_objects, Evas_Bool include_hidden_objects)
+EAPI Eina_List *
+evas_objects_in_rectangle_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects)
 {
-   Evas_List *in = NULL;
-   Evas_Object_List *l;
+   Eina_List *in = NULL;
+   Evas_Layer *lay;
    int xx, yy, ww, hh;
 
    MAGIC_CHECK(e, Evas, MAGIC_EVAS);
@@ -1384,7 +1549,7 @@ evas_objects_in_rectangle_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Co
    MAGIC_CHECK_END();
    xx = x;
    yy = y;
-   ww = w;                                
+   ww = w;
    hh = h;
 ////   xx = evas_coord_world_x_to_screen(e, x);
 ////   yy = evas_coord_world_y_to_screen(e, y);
@@ -1392,24 +1557,19 @@ evas_objects_in_rectangle_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Co
 ////   hh = evas_coord_world_y_to_screen(e, h);
    if (ww < 1) ww = 1;
    if (hh < 1) hh = 1;
-   for (l = ((Evas_Object_List *)(e->layers))->last; l; l = l->prev)
+   EINA_INLIST_REVERSE_FOREACH((EINA_INLIST_GET(e->layers)), lay)
      {
-	Evas_Object_List *l2;
-	Evas_Layer *lay;
+	Evas_Object *obj;
 
-	lay = (Evas_Layer *)l;
-	for (l2 = get_layer_objects_last(lay); l2; l2 = l2->prev)
+	EINA_INLIST_REVERSE_FOREACH(get_layer_objects_last(lay), obj)
 	  {
-	     Evas_Object *obj;
-
-	     obj = (Evas_Object *)l2;
 	     if (obj->delete_me) continue;
 	     if ((!include_pass_events_objects) && (evas_event_passes_through(obj))) continue;
 	     if ((!include_hidden_objects) && (!obj->cur.visible)) continue;
 	     evas_object_clip_recalc(obj);
 	     if ((evas_object_is_in_output_rect(obj, xx, yy, ww, hh)) &&
 		 (!obj->clip.clipees))
-	       in = evas_list_prepend(in, obj);
+	       in = eina_list_prepend(in, obj);
 	  }
      }
    return in;
@@ -1419,7 +1579,6 @@ evas_objects_in_rectangle_get(const Evas *e, Evas_Coord x, Evas_Coord y, Evas_Co
  * Retrieves the name of the type of the given evas object.
  * @param   obj The given object.
  * @return  The name.
- * @ingroup Evas_Object_Group
  */
 EAPI const char *
 evas_object_type_get(const Evas_Object *obj)
@@ -1436,10 +1595,9 @@ evas_object_type_get(const Evas_Object *obj)
  * @param obj The given object.
  * @param precise wheter to use a precise point collision detection or not
  * The default value is false.
- * @ingroup Evas_Object_Group
  */
 EAPI void
-evas_object_precise_is_inside_set(Evas_Object *obj, Evas_Bool precise)
+evas_object_precise_is_inside_set(Evas_Object *obj, Eina_Bool precise)
 {
    MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
    return;
@@ -1450,9 +1608,8 @@ evas_object_precise_is_inside_set(Evas_Object *obj, Evas_Bool precise)
 /**
  * Determine whether an object is set to use a precise point collision detection.
  * @param obj The given object.
- * @ingroup Evas_Object_Group
  */
-EAPI Evas_Bool
+EAPI Eina_Bool
 evas_object_precise_is_inside_get(const Evas_Object *obj)
 {
    MAGIC_CHECK(obj, Evas_Object, MAGIC_OBJ);
@@ -1460,3 +1617,7 @@ evas_object_precise_is_inside_get(const Evas_Object *obj)
    MAGIC_CHECK_END();
    return obj->precise_is_inside;
 }
+
+/**
+ * @}
+ */
