@@ -1,4 +1,13 @@
+/*
+ * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
+ */
+
 #include "evas_common.h"
+#include "evas_convert_rgb_8.h"
+#include "evas_convert_rgb_16.h"
+#include "evas_convert_rgb_24.h"
+#include "evas_convert_rgb_32.h"
+#include "evas_convert_yuv.h"
 
 #ifdef USE_DITHER_44
 const DATA8 _evas_dither_44[4][4] =
@@ -154,7 +163,7 @@ evas_common_convert_func_get(DATA8 *dest, int w, int h, int depth, DATA32 rmask,
 {
    if ((rmask == 0) && (gmask == 0) && (bmask == 0))
      {
- 	if (depth == 8)
+	if (depth == 8)
 	  {
 #ifdef BUILD_CONVERT_8_RGB_332
 	     if (pal_mode == PAL_MODE_RGB332)
@@ -185,10 +194,10 @@ evas_common_convert_func_get(DATA8 *dest, int w, int h, int depth, DATA32 rmask,
 	       return evas_common_convert_rgba_to_8bpp_rgb_111_dith;
 #endif
 	  }
- 	if (depth == 1)
+	if (depth == 1)
 	  {
 	  }
- 	if (depth == 4)
+	if (depth == 4)
 	  {
 	  }
      }
@@ -287,7 +296,7 @@ evas_common_convert_func_get(DATA8 *dest, int w, int h, int depth, DATA32 rmask,
 		       if ((!(w & 0x1)) && (!((intptr_t)dest & 0x3)))
 			 return evas_common_convert_rgba2_to_16bpp_rgb_555_dith;
 		       else
- 			 return evas_common_convert_rgba_to_16bpp_rgb_555_dith;
+			 return evas_common_convert_rgba_to_16bpp_rgb_555_dith;
 		    }
 #endif
 #ifdef BUILD_CONVERT_16_RGB_ROT180
@@ -445,7 +454,7 @@ evas_common_convert_func_get(DATA8 *dest, int w, int h, int depth, DATA32 rmask,
 	       }
 #endif
 	  }
- 	if (depth == 32)
+	if (depth == 32)
 	  {
 #ifdef BUILD_CONVERT_32_RGB_8888
 	     if ((rmask == 0x00ff0000) && (gmask == 0x0000ff00) && (bmask == 0x000000ff))
@@ -528,11 +537,32 @@ evas_common_convert_func_get(DATA8 *dest, int w, int h, int depth, DATA32 rmask,
 #ifdef BUILD_CONVERT_32_RGB_ROT90
 		  if (rotation == 90)
 		    return evas_common_convert_rgba_to_32bpp_bgrx_8888_rot_90;
+#endif
+	       }
+#endif
+#ifdef BUILD_CONVERT_32_RGB_666
+	     if ((rmask == 0x0003f000) && (gmask == 0x00000fc0) && (bmask == 0x0000003f))
+	       {
+#ifdef BUILD_CONVERT_32_RGB_ROT0
+		  if (rotation == 0)
+		    return evas_common_convert_rgba_to_32bpp_rgb_666;
+#endif
+#ifdef BUILD_CONVERT_32_RGB_ROT180
+//		  if (rotation == 180)
+//		    return evas_common_convert_rgba_to_32bpp_rgb_8888_rot_180;
+#endif
+#ifdef BUILD_CONVERT_32_RGB_ROT270
+//		  if (rotation == 270)
+//		    return evas_common_convert_rgba_to_32bpp_rgb_8888_rot_270;
+#endif
+#ifdef BUILD_CONVERT_32_RGB_ROT90
+//		  if (rotation == 90)
+//		    return evas_common_convert_rgba_to_32bpp_rgb_8888_rot_90;
 #endif
 	       }
 #endif
 	  }
- 	if (depth == 24)
+	if (depth == 24)
 	  {
 #ifdef BUILD_CONVERT_24_RGB_888
 	     if ((rmask == 0x00ff0000) && (gmask == 0x0000ff00) && (bmask == 0x000000ff))
@@ -541,6 +571,13 @@ evas_common_convert_func_get(DATA8 *dest, int w, int h, int depth, DATA32 rmask,
 		    return evas_common_convert_rgba_to_24bpp_rgb_888;
 	       }
 #endif
+#ifdef BUILD_CONVERT_24_RGB_666
+	     if ((rmask == 0x0003f000) && (gmask == 0x00000fc0) && (bmask == 0x0000003f))
+	       {
+		  if (rotation == 0)
+		    return evas_common_convert_rgba_to_24bpp_rgb_666;
+	       }
+#endif
 #ifdef BUILD_CONVERT_24_BGR_888
 	     if ((rmask == 0x000000ff) && (gmask == 0x0000ff00) && (bmask == 0x00ff0000))
 	       {
@@ -550,7 +587,7 @@ evas_common_convert_func_get(DATA8 *dest, int w, int h, int depth, DATA32 rmask,
 #endif
 	  }
 	printf("depth = %i mode = %i\n", depth, pal_mode);
- 	if (depth == 8)
+	if (depth == 8)
 	  {
 #ifdef BUILD_CONVERT_8_RGB_332
 	     if (pal_mode == PAL_MODE_RGB332)
@@ -581,10 +618,10 @@ evas_common_convert_func_get(DATA8 *dest, int w, int h, int depth, DATA32 rmask,
 	       return evas_common_convert_rgba_to_8bpp_rgb_111_dith;
 #endif
 	  }
- 	if (depth == 1)
+	if (depth == 1)
 	  {
 	  }
- 	if (depth == 4)
+	if (depth == 4)
 	  {
 	  }
     }
