@@ -94,6 +94,7 @@
 # define LKI(x) pthread_mutex_init(&(x), NULL);
 # define LKD(x) pthread_mutex_destroy(&(x));
 # define LKL(x) pthread_mutex_lock(&(x));
+# define LKT(x) pthread_mutex_trylock(&(x));
 # define LKU(x) pthread_mutex_unlock(&(x));
 # define TH(x)  pthread_t x
 # define THI(x) int x
@@ -108,6 +109,7 @@
 # define LKI(x)
 # define LKD(x)
 # define LKL(x)
+# define LKT(x) 0
 # define LKU(x)
 # define TH(x)
 # define THI(x)
@@ -410,16 +412,16 @@ struct _RGBA_Image_Loadopts
 
 struct _Image_Entry_Flags
 {
-   Evas_Bool loaded       : 1;
-   Evas_Bool dirty        : 1;
-   Evas_Bool activ        : 1;
-   Evas_Bool need_data    : 1;
-   Evas_Bool lru_nodata   : 1;
-   Evas_Bool cached       : 1;
-   Evas_Bool alpha        : 1;
-   Evas_Bool alpha_sparse : 1;
+   Eina_Bool loaded       : 1;
+   Eina_Bool dirty        : 1;
+   Eina_Bool activ        : 1;
+   Eina_Bool need_data    : 1;
+   Eina_Bool lru_nodata   : 1;
+   Eina_Bool cached       : 1;
+   Eina_Bool alpha        : 1;
+   Eina_Bool alpha_sparse : 1;
 #ifdef BUILD_ASYNC_PRELOAD
-   Evas_Bool preload      : 1;
+   Eina_Bool preload      : 1;
 #endif
 };
 
@@ -434,38 +436,38 @@ struct _Image_Entry
    EINA_INLIST;
 
    Evas_Cache_Image      *cache;
-   
+
    const char            *cache_key;
-   
+
    const char            *file;
    const char            *key;
-   
+
    Evas_Cache_Target     *targets;
-   
+
    time_t                 timestamp;
    time_t                 laststat;
-   
+
    int                    references;
-   
+
    unsigned char          scale;
-   
+
    RGBA_Image_Loadopts    load_opts;
    int                    space;
    int                    w;
    int                    h;
-   
+
    struct
      {
         int		 w;
         int		 h;
      } allocated;
-   
+
    struct
      {
         void		*module;
         void		*loader;
      } info;
-   
+
 #ifdef BUILD_ASYNC_PRELOAD
    LK(lock);
 #endif
@@ -490,11 +492,11 @@ struct _Engine_Image_Entry
 
    struct
    {
-     Evas_Bool                   cached : 1;
-     Evas_Bool                   activ : 1;
-     Evas_Bool                   dirty : 1;
-     Evas_Bool                   loaded : 1;
-     Evas_Bool                   need_parent : 1;
+     Eina_Bool                   cached : 1;
+     Eina_Bool                   activ : 1;
+     Eina_Bool                   dirty : 1;
+     Eina_Bool                   loaded : 1;
+     Eina_Bool                   need_parent : 1;
    } flags;
 
    int                           references;
@@ -524,7 +526,7 @@ struct _Evas_Common_Transform
 struct _RGBA_Draw_Context
 {
    struct {
-      Evas_Bool use : 1;
+      Eina_Bool use : 1;
       DATA32 col;
    } mul;
    struct {
@@ -532,7 +534,7 @@ struct _RGBA_Draw_Context
    } col;
    struct RGBA_Draw_Context_clip {
       int    x, y, w, h;
-      Evas_Bool use : 1;
+      Eina_Bool use : 1;
    } clip;
    Cutout_Rects cutout;
    struct {
@@ -550,7 +552,7 @@ struct _RGBA_Draw_Context
       int y, h;
    } sli;
    int            render_op;
-   Evas_Bool anti_alias : 1;
+   Eina_Bool anti_alias : 1;
 };
 
 #ifdef BUILD_PIPE_RENDER
@@ -615,9 +617,9 @@ struct _RGBA_Image
    RGBA_Image_Flags     flags;
    struct
      {
-/* 	void           *module; */
-/* 	void           *loader; */
-/* 	char           *real_file; */
+/*	void           *module; */
+/*	void           *loader; */
+/*	char           *real_file; */
 	char           *comment;
 //	int             format;
      } info;
@@ -625,7 +627,7 @@ struct _RGBA_Image
    void                *extended_info;
 #ifdef BUILD_PIPE_RENDER
    RGBA_Pipe           *pipe;
-#endif   
+#endif
    int                  ref;
 
 /*    unsigned char        scale; */
@@ -633,16 +635,16 @@ struct _RGBA_Image
    /* Colorspace stuff. */
    struct {
       void              *data;
-      Evas_Bool          no_free : 1;
-      Evas_Bool          dirty : 1;
+      Eina_Bool          no_free : 1;
+      Eina_Bool          dirty : 1;
    } cs;
 
    /* RGBA stuff */
    struct {
       DATA32            *data;
-      Evas_Bool          no_free : 1;
+      Eina_Bool          no_free : 1;
    } image;
-   
+
    struct {
       LK(lock);
       Eina_List *list;
@@ -677,7 +679,7 @@ struct _RGBA_Gradient
 	float          angle;
 	int            direction;
 	float          offset;
-	Evas_Bool      has_alpha : 1;
+	Eina_Bool      has_alpha : 1;
      } map;
 
    struct {
@@ -709,8 +711,8 @@ struct _RGBA_Gradient
 
    int references;
 
-   Evas_Bool imported_data : 1;
-   Evas_Bool has_alpha : 1;
+   Eina_Bool imported_data : 1;
+   Eina_Bool has_alpha : 1;
 };
 
 struct _RGBA_Gradient_Type
@@ -741,7 +743,7 @@ struct _RGBA_Gradient2
      {
 	DATA32        *data;
 	int            len;
-	Evas_Bool      has_alpha : 1;
+	Eina_Bool      has_alpha : 1;
      } map;
 
    struct {
@@ -766,7 +768,7 @@ struct _RGBA_Gradient2
 
    int references;
 
-   Evas_Bool has_alpha : 1;
+   Eina_Bool has_alpha : 1;
 };
 
 struct _RGBA_Gradient2_Type
@@ -800,8 +802,6 @@ struct _RGBA_Font
 
 struct _RGBA_Font_Int
 {
-   EINA_INLIST;
-
    RGBA_Font_Source *src;
 
    int               size;
@@ -814,7 +814,7 @@ struct _RGBA_Font_Int
    Eina_Hash       *glyphs;
 
    LK(ft_mutex);
-   
+
    Eina_Hash       *kerning;
    Eina_Hash       *indexes;
 
@@ -822,19 +822,20 @@ struct _RGBA_Font_Int
    Font_Hint_Flags hinting;
 
    int              references;
+
 };
 
 struct _RGBA_Font_Source
 {
-   EINA_INLIST;
-
    const char       *name;
    const char       *file;
 
    void             *data;
    int               data_size;
    int               current_size;
+#if 0 /* FIXME: charmap user is disabled and use a deprecated data type. */
    Evas_Array_Hash  *charmap;
+#endif
 
    struct {
       int           orig_upem;
@@ -846,6 +847,7 @@ struct _RGBA_Font_Source
 
 struct _RGBA_Font_Glyph
 {
+   FT_UInt         index;
    FT_Glyph        glyph;
    FT_BitmapGlyph  glyph_out;
    /* this is a problem - only 1 engine at a time can extend such a font... grrr */
@@ -954,12 +956,12 @@ struct _Tilebuf
 
 struct _Tilebuf_Tile
 {
-   Evas_Bool redraw : 1;
+   Eina_Bool redraw : 1;
 /* FIXME: need these flags later - but not now */
 /*
-   Evas_Bool done   : 1;
-   Evas_Bool edge   : 1;
-   Evas_Bool from   : 1;
+   Eina_Bool done   : 1;
+   Eina_Bool edge   : 1;
+   Eina_Bool from   : 1;
 
    struct {
       int dx, dy;
@@ -1130,7 +1132,7 @@ Tilebuf_Rect *evas_common_regionbuf_rects_get (Regionbuf *rb);
 #ifdef BUILD_PIPE_RENDER
 # include "../engines/common/evas_pipe.h"
 #endif
-   
+
 void              evas_font_dir_cache_free(void);
 
 /****/
@@ -1141,8 +1143,8 @@ void              evas_font_dir_cache_free(void);
 #ifdef BUILD_NEON
 # include <arm_neon.h>
 #endif
-#endif   
-   
+#endif
+
 #ifdef __cplusplus
 }
 #endif
