@@ -28,15 +28,6 @@ static IDirectFB *dfb = NULL; /* XXX HACK to work around evas image cache
 /***********************************************************************
  * Evas helpers
  **********************************************************************/
-static void
-_rect_set(Evas_Rectangle *r, int x, int y, int w, int h)
-{
-   r->x = x;
-   r->y = y;
-   r->w = w;
-   r->h = h;
-}
-
 static void
 _context_get_color(RGBA_Draw_Context *dc, int *r, int *g, int *b, int *a)
 {
@@ -689,7 +680,7 @@ evas_engine_dfb_info_free(Evas *e __UNUSED__, void *in)
    free(info);
 }
 
-static Evas_Bool
+static Eina_Bool
 _is_dfb_data_ok(IDirectFB *idfb, IDirectFBSurface *surface, int w, int h)
 {
    DFBResult r;
@@ -698,14 +689,14 @@ _is_dfb_data_ok(IDirectFB *idfb, IDirectFBSurface *surface, int w, int h)
    if (!idfb)
      {
 	fputs("ERROR: missing IDirectFB\n", stderr);
-	return 0;
+	return EINA_FALSE;
      }
    dfb = idfb;
 
    if (!surface)
      {
 	fputs("ERROR: missing IDirectFBSurface\n", stderr);
-	return 0;
+	return EINA_FALSE;
      }
 
    r = surface->GetSize(surface, &sw, &sh);
@@ -713,7 +704,7 @@ _is_dfb_data_ok(IDirectFB *idfb, IDirectFBSurface *surface, int w, int h)
      {
 	fprintf(stderr, "ERROR: could not get surface %p size: %s\n",
 		surface, DirectFBErrorString(r));
-	return 0;
+	return EINA_FALSE;
      }
 
    if ((w > sw) || (h > sh))
@@ -721,7 +712,7 @@ _is_dfb_data_ok(IDirectFB *idfb, IDirectFBSurface *surface, int w, int h)
 	fprintf(stderr,
 		"ERROR: requested size is larger than surface: %dx%d > %dx%d\n",
 		w, h, sw, sh);
-	return 0;
+	return EINA_FALSE;
      }
    else if ((w <= 0) || (h <= 0))
      {
@@ -729,7 +720,7 @@ _is_dfb_data_ok(IDirectFB *idfb, IDirectFBSurface *surface, int w, int h)
 	h = sh;
      }
 
-   return 1;
+   return EINA_TRUE;
 }
 
 static void
@@ -950,8 +941,6 @@ evas_engine_dfb_output_redraws_next_update_get(void *data, int *x, int *y, int *
 	re->end = 1;
      }
 
-   _image_clear(re->screen_image, *x, *y, *w, *h );
-
    return re->screen_image->surface;
 }
 
@@ -1070,7 +1059,7 @@ evas_engine_dfb_font_draw(void *data, void *context, void *surface, void *font,
 static void
 _cb_draw_line(IDirectFBSurface *surface, RGBA_Draw_Context *dc __UNUSED__, const DFBRegion *region __UNUSED__, void *data)
 {
-   const Evas_Rectangle *r = data;
+   const Eina_Rectangle *r = data;
 
    surface->DrawLine(surface, r->x, r->y, r->w, r->h); /* x2, y2 really */
 }
@@ -1079,12 +1068,12 @@ static void
 evas_engine_dfb_line_draw(void *data __UNUSED__, void *context, void *surface, int x1, int y1, int x2, int y2)
 {
    IDirectFBSurface *screen = surface;
-   Evas_Rectangle r;
+   Eina_Rectangle r;
 
    if (!_dfb_surface_set_color_from_context(screen, context))
      return;
 
-   _rect_set(&r, x1, y1, x2, y2); /* x2, y2 (ab)used as w, h */
+   EINA_RECTANGLE_SET(&r, x1, y1, x2, y2); /* x2, y2 (ab)used as w, h */
    _dfb_surface_for_each_cutout(screen, context, _cb_draw_line, &r);
 }
 
@@ -1092,7 +1081,7 @@ evas_engine_dfb_line_draw(void *data __UNUSED__, void *context, void *surface, i
 static void
 _cb_draw_rectangle(IDirectFBSurface *surface, RGBA_Draw_Context *dc __UNUSED__, const DFBRegion *region __UNUSED__, void *data)
 {
-   const Evas_Rectangle *r = data;
+   const Eina_Rectangle *r = data;
 
    surface->FillRectangle(surface, r->x, r->y, r->w, r->h);
 }
@@ -1101,12 +1090,12 @@ static void
 evas_engine_dfb_rectangle_draw(void *data __UNUSED__, void *context, void *surface, int x, int y, int w, int h)
 {
    IDirectFBSurface *screen = surface;
-   Evas_Rectangle r;
+   Eina_Rectangle r;
 
    if (!_dfb_surface_set_color_from_context(screen, context))
      return;
 
-   _rect_set(&r, x, y, w, h);
+   EINA_RECTANGLE_SET(&r, x, y, w, h);
    _dfb_surface_for_each_cutout(screen, context, _cb_draw_rectangle, &r);
 }
 #else
@@ -1611,7 +1600,15 @@ evas_engine_dfb_image_scale_hint_get(void *data __UNUSED__, void *image)
    return EVAS_IMAGE_SCALE_HINT_NONE;
 }
 
-EAPI int
+static Eina_Bool
+evas_engine_dfb_canvas_alpha_get(void *data, void *context)
+{
+   Render_Engine *re = data;
+
+   return re->screen_image->cache_entry.src->flags.alpha;
+}
+
+static int
 module_open(Evas_Module *em)
 {
    if (!em) return 0;
@@ -1666,15 +1663,24 @@ module_open(Evas_Module *em)
    return 1;
 }
 
-EAPI void
-module_close(void)
+static void
+module_close(Evas_Module *em)
 {
 }
 
-EAPI Evas_Module_Api evas_modapi =
+static Evas_Module_Api evas_modapi =
 {
-   EVAS_MODULE_API_VERSION,
-   EVAS_MODULE_TYPE_ENGINE,
-   "directfb",
-   "ProFUSION embedded systems"
+  EVAS_MODULE_API_VERSION,
+  "directfb",
+  "ProFUSION embedded systems",
+  {
+    module_open,
+    module_close
+  }
 };
+
+EVAS_MODULE_DEFINE(EVAS_MODULE_TYPE_ENGINE, engine, directfb);
+
+#ifndef EVAS_STATIC_BUILD_DIRECTFB
+EVAS_EINA_MODULE_DEFINE(engine, directfb);
+#endif
