@@ -368,8 +368,6 @@ evas_engine_sdl16_output_redraws_next_update_get(void *data,
    rect.w = *w;
    rect.h = *h;
 
-   SDL_FillRect(re->soft16_engine_image->surface, &rect, 0);
-
    /* Return the "fake" surface so it is passed to the drawing routines. */
    return re->soft16_engine_image;
 }
@@ -1018,8 +1016,14 @@ evas_engine_sdl16_image_stride_get(void *data __UNUSED__, void *image, int *stri
    if (stride) *stride = ((Soft16_Image*) eim->cache_entry.src)->stride;
 }
 
+static Eina_Bool
+evas_engine_sdl16_canvas_alpha_get(void *data, void *context)
+{
+   return EINA_FALSE;
+}
+
 /* module advertising code */
-EAPI int
+static int
 module_open(Evas_Module *em)
 {
    if (!em) return 0;
@@ -1032,6 +1036,7 @@ module_open(Evas_Module *em)
    ORD(info);
    ORD(info_free);
    ORD(setup);
+   ORD(canvas_alpha_get);
    ORD(output_free);
    ORD(output_resize);
    ORD(output_tile_size_set);
@@ -1079,19 +1084,28 @@ module_open(Evas_Module *em)
    return 1;
 }
 
-EAPI void
-module_close(void)
+static void
+module_close(Evas_Module *em)
 {
 }
 
-EAPI Evas_Module_Api evas_modapi = 
+static Evas_Module_Api evas_modapi =
 {
-   EVAS_MODULE_API_VERSION, 
-     EVAS_MODULE_TYPE_ENGINE,
-     "software_16_sdl",
-     "none"
+   EVAS_MODULE_API_VERSION,
+   "software_16_sdl",
+   "none",
+   {
+     module_open,
+     module_close
+   }
 };
 
+EVAS_MODULE_DEFINE(EVAS_MODULE_TYPE_ENGINE, engine, software_16_sdl);
+
+#ifndef EVAS_STATIC_BUILD_SOFTWARE_SDL
+EVAS_EINA_MODULE_DEFINE(engine, software_16_sdl);
+#endif
+
 static Engine_Image_Entry*
 _sdl16_image_alloc(void)
 {
