@@ -9,7 +9,8 @@ typedef enum
 {
   EVAS_ENGINE_WINCE_FB,
   EVAS_ENGINE_WINCE_GAPI,
-  EVAS_ENGINE_WINCE_DDRAW
+  EVAS_ENGINE_WINCE_DDRAW,
+  EVAS_ENGINE_WINCE_GDI
 } Evas_Engine_WinCE_Backend;
 
 
@@ -21,7 +22,7 @@ typedef struct _Render_Engine Render_Engine;
 
 struct _Render_Engine
 {
-   Evas_Engine_WinCE_Backend backend; /* 1: raw, 2: gapi, 3: ddraw */
+   Evas_Engine_WinCE_Backend backend; /* 1: raw, 2: gapi, 3: ddraw, 4: GDI */
    void               *backend_priv;
    void              (*backend_shutdown)(void *priv);
    FB_Output_Buffer *(*backend_output_buffer_new)(void *priv,
@@ -47,7 +48,7 @@ struct _Render_Engine
 
 static void *eng_info(Evas *e);
 static void eng_info_free(Evas *e, void *info);
-static void eng_setup(Evas *e, void *info);
+static int eng_setup(Evas *e, void *info);
 static void eng_output_free(void *data);
 static void eng_output_resize(void *data, int w, int h);
 static void eng_output_tile_size_set(void *data, int w, int h);
@@ -113,7 +114,7 @@ _tmp_out_alloc(Render_Engine *re)
    Tilebuf_Rect *r;
    int w = 0, h = 0;
 
-   for (r = re->rects; r; r = (Tilebuf_Rect *)(r->_list_data.next))
+   EINA_INLIST_FOREACH(re->rects, r)
      {
 	if (r->w > w) w = r->w;
 	if (r->h > h) h = r->h;
@@ -141,7 +142,7 @@ _tmp_out_alloc(Render_Engine *re)
 }
 
 
-static void
+static int
 eng_setup(Evas *e, void *in)
 {
    Render_Engine                      *re;
@@ -170,7 +171,7 @@ eng_setup(Evas *e, void *in)
 	/* render engine specific data */
 	re = calloc(1, sizeof(Render_Engine));
         if (!re)
-          return;
+          return 0;
 	e->engine.data.output = re;
 
         switch(info->info.backend)
@@ -181,7 +182,7 @@ eng_setup(Evas *e, void *in)
               if (!re->backend_priv)
                 {
                    free(re);
-                   return;
+                   return 0;
                 }
               re->backend_shutdown = evas_software_wince_fb_shutdown;
               re->backend_output_buffer_new = evas_software_wince_fb_output_buffer_new;
@@ -195,7 +196,7 @@ eng_setup(Evas *e, void *in)
               if (!re->backend_priv)
                 {
                    free(re);
-                   return;
+                   return 0;
                 }
               re->backend_shutdown = evas_software_wince_gapi_shutdown;
               re->backend_output_buffer_new = evas_software_wince_gapi_output_buffer_new;
@@ -209,7 +210,7 @@ eng_setup(Evas *e, void *in)
               if (!re->backend_priv)
                 {
                    free(re);
-                   return;
+                   return 0;
                 }
               re->backend_shutdown = evas_software_wince_ddraw_shutdown;
               re->backend_output_buffer_new = evas_software_wince_ddraw_output_buffer_new;
@@ -217,9 +218,23 @@ eng_setup(Evas *e, void *in)
               re->backend_output_buffer_paste = evas_software_wince_ddraw_output_buffer_paste;
               re->backend_surface_resize = evas_software_wince_ddraw_surface_resize;
               break;
+           case 4: /* GDI */
+              re->backend = EVAS_ENGINE_WINCE_GDI;
+              re->backend_priv = evas_software_wince_gdi_init(info->info.window, info->info.width, info->info.height, info->info.fullscreen);
+              if (!re->backend_priv)
+                {
+                   free(re);
+                   return 0;
+                }
+              re->backend_shutdown = evas_software_wince_gdi_shutdown;
+              re->backend_output_buffer_new = evas_software_wince_gdi_output_buffer_new;
+              re->backend_output_buffer_free = evas_software_wince_gdi_output_buffer_free;
+              re->backend_output_buffer_paste = evas_software_wince_gdi_output_buffer_paste;
+              re->backend_surface_resize = evas_software_wince_gdi_surface_resize;
+              break;
            default:
               free(re);
-              return;
+              return 0;
           }
 
 	re->width = e->output.w;
@@ -242,7 +257,7 @@ eng_setup(Evas *e, void *in)
               if (!re->backend_priv)
                 {
                    free(re);
-                   return;
+                   return 0;
                 }
               re->backend_shutdown = evas_software_wince_fb_shutdown;
               re->backend_output_buffer_new = evas_software_wince_fb_output_buffer_new;
@@ -256,7 +271,7 @@ eng_setup(Evas *e, void *in)
               if (!re->backend_priv)
                 {
                    free(re);
-                   return;
+                   return 0;
                 }
               re->backend_shutdown = evas_software_wince_gapi_shutdown;
               re->backend_output_buffer_new = evas_software_wince_gapi_output_buffer_new;
@@ -270,7 +285,7 @@ eng_setup(Evas *e, void *in)
               if (!re->backend_priv)
                 {
                    free(re);
-                   return;
+                   return 0;
                 }
               re->backend_shutdown = evas_software_wince_ddraw_shutdown;
               re->backend_output_buffer_new = evas_software_wince_ddraw_output_buffer_new;
@@ -278,9 +293,23 @@ eng_setup(Evas *e, void *in)
               re->backend_output_buffer_paste = evas_software_wince_ddraw_output_buffer_paste;
               re->backend_surface_resize = evas_software_wince_ddraw_surface_resize;
               break;
+           case 4: /* GDI */
+              re->backend = EVAS_ENGINE_WINCE_GDI;
+              re->backend_priv = evas_software_wince_gdi_init(info->info.window, info->info.width, info->info.height, info->info.fullscreen);
+              if (!re->backend_priv)
+                {
+                   free(re);
+                   return 0;
+                }
+              re->backend_shutdown = evas_software_wince_gdi_shutdown;
+              re->backend_output_buffer_new = evas_software_wince_gdi_output_buffer_new;
+              re->backend_output_buffer_free = evas_software_wince_gdi_output_buffer_free;
+              re->backend_output_buffer_paste = evas_software_wince_gdi_output_buffer_paste;
+              re->backend_surface_resize = evas_software_wince_gdi_surface_resize;
+              break;
            default:
               free(re);
-              return;
+              return 0;
           }
 
 	re->width = e->output.w;
@@ -295,11 +324,13 @@ eng_setup(Evas *e, void *in)
 	     re->tmp_out = NULL;
 	  }
      }
-   if (!e->engine.data.output) return;
+   if (!e->engine.data.output) return 0;
    /* add a draw context if we dont have one */
    if (!e->engine.data.context)
      e->engine.data.context =
      e->engine.func->context_new(e->engine.data.output);
+
+   return 1;
 }
 
 static void
@@ -447,7 +478,7 @@ eng_output_redraws_next_update_get(void *data, int *x, int *y, int *w, int *h, i
      }
    rect = re->cur_rect;
    ux = rect->x; uy = rect->y; uw = rect->w; uh = rect->h;
-   re->cur_rect = (Tilebuf_Rect *)(re->cur_rect->_list_data.next);
+   re->cur_rect = (Tilebuf_Rect *)((EINA_INLIST_GET(re->cur_rect))->next);
    if (!re->cur_rect)
      {
 	evas_common_tilebuf_free_render_rects(re->rects);
@@ -672,9 +703,14 @@ eng_output_idle_flush(void *data)
      }
 }
 
+static Eina_Bool
+eng_canvas_alpha_get(void *data, void *context)
+{
+   return EINA_FALSE;
+}
 
 /* module advertising code */
-EAPI int
+static int
 module_open(Evas_Module *em)
 {
    if (!em) return 0;
@@ -687,6 +723,7 @@ module_open(Evas_Module *em)
    ORD(info);
    ORD(info_free);
    ORD(setup);
+   ORD(canvas_alpha_get);
    ORD(output_free);
    ORD(output_resize);
    ORD(output_tile_size_set);
@@ -702,15 +739,24 @@ module_open(Evas_Module *em)
    return 1;
 }
 
-EAPI void
-module_close(void)
+static void
+module_close(Evas_Module *em)
 {
 }
 
-EAPI Evas_Module_Api evas_modapi =
+static Evas_Module_Api evas_modapi =
 {
    EVAS_MODULE_API_VERSION,
-   EVAS_MODULE_TYPE_ENGINE,
-   "software_16_wince_fb",
-   "none"
+   "software_16_wince",
+   "none",
+   {
+     module_open,
+     module_close
+   }
 };
+
+EVAS_MODULE_DEFINE(EVAS_MODULE_TYPE_ENGINE, engine, software_16_wince);
+
+#ifndef EVAS_STATIC_BUILD_SOFTWARE_16_WINCE
+EVAS_EINA_MODULE_DEFINE(engine, software_16_wince);
+#endif
