@@ -961,6 +961,11 @@ eng_font_hinting_can_hint(void *data __UNUSED__, int hinting)
    return evas_common_hinting_available(hinting);
 }
 
+static Eina_Bool
+eng_canvas_alpha_get(void *data __UNUSED__, void *info __UNUSED__)
+{
+   return EINA_TRUE;
+}
 
 /*
  *****
@@ -987,6 +992,7 @@ static Evas_Func func =
      NULL,
      /* draw context virtual methods */
      eng_context_new,
+     eng_canvas_alpha_get,
      eng_context_free,
      eng_context_clip_set,
      eng_context_clip_clip,
@@ -1121,7 +1127,7 @@ static Evas_Func func =
  *****
  */
 
-EAPI int
+static int
 module_open(Evas_Module *em)
 {
    if (!em) return 0;
@@ -1130,15 +1136,24 @@ module_open(Evas_Module *em)
    return 1;
 }
 
-EAPI void
-module_close(void)
+static void
+module_close(Evas_Module *em)
 {
 }
 
-EAPI Evas_Module_Api evas_modapi = 
+static Evas_Module_Api evas_modapi =
 {
-   EVAS_MODULE_API_VERSION, 
-     EVAS_MODULE_TYPE_ENGINE,
-     "software_generic",
-     "none"
+   EVAS_MODULE_API_VERSION,
+   "software_generic",
+   "none",
+   {
+     module_open,
+     module_close
+   }
 };
+
+EVAS_MODULE_DEFINE(EVAS_MODULE_TYPE_ENGINE, engine, software_generic);
+
+#ifndef EVAS_STATIC_BUILD_SOFTWARE_GENERIC
+EVAS_EINA_MODULE_DEFINE(engine, software_generic);
+#endif
