@@ -4,8 +4,11 @@
 #include "Evas_Engine_Software_X11.h"
 
 #include "evas_engine.h"
-#include "evas_xlib_outbuf.h"
-#include "evas_xlib_color.h"
+
+#ifdef BUILD_ENGINE_SOFTWARE_XLIB
+# include "evas_xlib_outbuf.h"
+# include "evas_xlib_color.h"
+#endif
 
 #ifdef BUILD_ENGINE_SOFTWARE_XCB
 # include "evas_xcb_outbuf.h"
@@ -34,11 +37,10 @@ struct _Render_Engine
    void        (*outbuf_free_region_for_update)(Outbuf *ob, RGBA_Image *update);
    void        (*outbuf_flush)(Outbuf *ob);
    void        (*outbuf_idle_flush)(Outbuf *ob);
+   Eina_Bool   (*outbuf_alpha_get)(Outbuf *ob);
 };
 
 /* prototypes we will use here */
-static void *_output_xlib_setup(int w, int h, int rot, Display *disp, Drawable draw, Visual *vis, Colormap cmap, int depth, int debug, int grayscale, int max_colors, Pixmap mask, int shape_dither, int destination_alpha);
-
 static void        *_best_visual_get   (int backend, void *connection, int screen);
 static unsigned int _best_colormap_get (int backend, void *connection, int screen);
 static int          _best_depth_get    (int backend, void *connection, int screen);
@@ -60,6 +62,7 @@ static void eng_output_idle_flush(void *data);
 
 /* internal engine routines */
 
+#ifdef BUILD_ENGINE_SOFTWARE_XLIB
 static void *
 _output_xlib_setup(int      w,
                    int      h,
@@ -127,6 +130,7 @@ _output_xlib_setup(int      w,
    evas_common_tilebuf_set_tile_size(re->tb, TILESIZE, TILESIZE);
    return re;
 }
+#endif
 
 #ifdef BUILD_ENGINE_SOFTWARE_XCB
 static void *
@@ -205,13 +209,15 @@ _best_visual_get(int backend, void *connection, int screen)
 {
    if (!connection) return NULL;
 
-   if (backend == 0)
+#ifdef BUILD_ENGINE_SOFTWARE_XLIB
+   if (backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XLIB)
      {
         return DefaultVisual((Display *)connection, screen);
      }
+#endif
 
 #ifdef BUILD_ENGINE_SOFTWARE_XCB
-   if (backend == 1)
+   if (backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XCB)
      {
         xcb_screen_iterator_t iter_screen;
         xcb_depth_iterator_t  iter_depth;
@@ -248,13 +254,15 @@ _best_colormap_get(int backend, void *connection, int screen)
 {
    if (!connection) return 0;
 
-   if (backend == 0)
+#ifdef BUILD_ENGINE_SOFTWARE_XLIB
+   if (backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XLIB)
      {
         return DefaultColormap((Display *)connection, screen);
      }
+#endif
 
 #ifdef BUILD_ENGINE_SOFTWARE_XCB
-   if (backend == 1)
+   if (backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XCB)
      {
         xcb_screen_iterator_t iter_screen;
         xcb_screen_t          *s;
@@ -279,13 +287,15 @@ _best_depth_get(int backend, void *connection, int screen)
 {
    if (!connection) return 0;
 
-   if (backend == 0)
+#ifdef BUILD_ENGINE_SOFTWARE_XLIB
+   if (backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XLIB)
      {
         return DefaultDepth((Display *)connection, screen);
      }
+#endif
 
 #ifdef BUILD_ENGINE_SOFTWARE_XCB
-   if (backend == 1)
+   if (backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XCB)
      {
         xcb_screen_iterator_t iter_screen;
         xcb_screen_t          *s;
@@ -355,7 +365,8 @@ eng_setup(Evas *e, void *in)
         evas_common_draw_init();
         evas_common_tilebuf_init();
 
-        if (info->info.backend == 0)
+#ifdef BUILD_ENGINE_SOFTWARE_XLIB
+        if (info->info.backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XLIB)
           {
              re = _output_xlib_setup(e->output.w,
                                      e->output.h,
@@ -380,10 +391,12 @@ eng_setup(Evas *e, void *in)
              re->outbuf_free_region_for_update = evas_software_xlib_outbuf_free_region_for_update;
              re->outbuf_flush = evas_software_xlib_outbuf_flush;
              re->outbuf_idle_flush = evas_software_xlib_outbuf_idle_flush;
+	     re->outbuf_alpha_get = evas_software_xlib_outbuf_alpha_get;
           }
+#endif
 
 #ifdef BUILD_ENGINE_SOFTWARE_XCB
-        if (info->info.backend == 1)
+        if (info->info.backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XCB)
           {
              re = _output_xcb_setup(e->output.w,
                                     e->output.h,
@@ -409,6 +422,7 @@ eng_setup(Evas *e, void *in)
              re->outbuf_free_region_for_update = evas_software_xcb_outbuf_free_region_for_update;
              re->outbuf_flush = evas_software_xcb_outbuf_flush;
              re->outbuf_idle_flush = evas_software_xcb_outbuf_idle_flush;
+	     re->outbuf_alpha_get = evas_software_xcb_outbuf_alpha_get;
           }
 #endif
 
@@ -421,7 +435,8 @@ eng_setup(Evas *e, void *in)
 	re = e->engine.data.output;
 	ponebuf = re->ob->onebuf;
 
-        if (info->info.backend == 0)
+#ifdef BUILD_ENGINE_SOFTWARE_XLIB
+        if (info->info.backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XLIB)
           {
              evas_software_xlib_outbuf_free(re->ob);
              re->ob = evas_software_xlib_outbuf_setup_x(e->output.w,
@@ -440,9 +455,10 @@ eng_setup(Evas *e, void *in)
                                                         info->info.destination_alpha);
              evas_software_xlib_outbuf_debug_set(re->ob, info->info.debug);
           }
+#endif
 
 #ifdef BUILD_ENGINE_SOFTWARE_XCB
-        if (info->info.backend == 1)
+        if (info->info.backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XCB)
           {
              evas_software_xcb_outbuf_free(re->ob);
              re->ob = evas_software_xcb_outbuf_setup_x(e->output.w,
@@ -611,9 +627,17 @@ eng_output_idle_flush(void *data)
    re->outbuf_idle_flush(re->ob);
 }
 
+static Eina_Bool
+eng_canvas_alpha_get(void *data, void *context)
+{
+   Render_Engine *re;
+
+   re = (Render_Engine *)data;
+   return (re->ob->priv.destination_alpha) || (re->outbuf_alpha_get(re->ob));
+}
 
 /* module advertising code */
-EAPI int
+static int
 module_open(Evas_Module *em)
 {
    if (!em) return 0;
@@ -626,6 +650,7 @@ module_open(Evas_Module *em)
    ORD(info);
    ORD(info_free);
    ORD(setup);
+   ORD(canvas_alpha_get);
    ORD(output_free);
    ORD(output_resize);
    ORD(output_tile_size_set);
@@ -641,15 +666,25 @@ module_open(Evas_Module *em)
    return 1;
 }
 
-EAPI void
-module_close(void)
+static void
+module_close(Evas_Module *em)
 {
 }
 
-EAPI Evas_Module_Api evas_modapi =
+static Evas_Module_Api evas_modapi =
 {
    EVAS_MODULE_API_VERSION,
-     EVAS_MODULE_TYPE_ENGINE,
-     "software_x11",
-     "none"
+   "software_x11",
+   "none",
+   {
+     module_open,
+     module_close
+   }
 };
+
+EVAS_MODULE_DEFINE(EVAS_MODULE_TYPE_ENGINE, engine, software_x11);
+
+#ifndef EVAS_STATIC_BUILD_SOFTWARE_X11
+EVAS_EINA_MODULE_DEFINE(engine, software_x11);
+#endif
+
