@@ -1,14 +1,22 @@
-#include "evas_common.h"
-#include "evas_private.h"
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
 
 #include <stdio.h>
 #include <tiffio.h>
 
+#ifdef HAVE_EVIL
+# include <Evil.h>
+#endif
 
-int evas_image_load_file_head_tiff(Image_Entry *ie, const char *file, const char *key);
-int evas_image_load_file_data_tiff(Image_Entry *ie, const char *file, const char *key);
+#include "evas_common.h"
+#include "evas_private.h"
 
-Evas_Image_Load_Func evas_image_load_tiff_func =
+static int evas_image_load_file_head_tiff(Image_Entry *ie, const char *file, const char *key);
+static int evas_image_load_file_data_tiff(Image_Entry *ie, const char *file, const char *key);
+
+static Evas_Image_Load_Func evas_image_load_tiff_func =
 {
   evas_image_load_file_head_tiff,
   evas_image_load_file_data_tiff
@@ -70,7 +78,7 @@ raster(TIFFRGBAImage_Extra * img, uint32 * rast,
    uint32             *pixel, pixel_value;
    int                 i, j, dy, rast_offset;
    DATA32             *buffer_pixel, *buffer = evas_cache_image_pixels(img->image);
-   int                 alpha_premult;
+   int                 alpha_premult = 0;
 
    image_width = img->image->w;
    image_height = img->image->h;
@@ -109,8 +117,8 @@ raster(TIFFRGBAImage_Extra * img, uint32 * rast,
      }
 }
 
-int
-evas_image_load_file_head_tiff(Image_Entry *ie, const char *file, const char *key)
+static int
+evas_image_load_file_head_tiff(Image_Entry *ie, const char *file, const char *key __UNUSED__)
 {
    char                txt[1024];
    TIFFRGBAImage       tiff_image;
@@ -174,12 +182,13 @@ evas_image_load_file_head_tiff(Image_Entry *ie, const char *file, const char *ke
    ie->w = tiff_image.width;
    ie->h = tiff_image.height;
 
+   TIFFRGBAImageEnd(&tiff_image);
    TIFFClose(tif);
    return 1;
 }
 
-int
-evas_image_load_file_data_tiff(Image_Entry *ie, const char *file, const char *key)
+static int
+evas_image_load_file_data_tiff(Image_Entry *ie, const char *file, const char *key __UNUSED__)
 {
    char                txt[1024];
    TIFFRGBAImage_Extra rgba_image;
@@ -315,7 +324,7 @@ evas_image_load_file_data_tiff(Image_Entry *ie, const char *file, const char *ke
    return 1;
 }
 
-EAPI int
+static int
 module_open(Evas_Module *em)
 {
    if (!em) return 0;
@@ -323,16 +332,25 @@ module_open(Evas_Module *em)
    return 1;
 }
 
-EAPI void
-module_close(void)
+static void
+module_close(Evas_Module *em)
 {
 
 }
 
-EAPI Evas_Module_Api evas_modapi =
+static Evas_Module_Api evas_modapi =
 {
    EVAS_MODULE_API_VERSION,
-     EVAS_MODULE_TYPE_IMAGE_LOADER,
-     "tiff",
-     "none"
+   "tiff",
+   "none",
+   {
+     module_open,
+     module_close
+   }
 };
+
+EVAS_MODULE_DEFINE(EVAS_MODULE_TYPE_IMAGE_LOADER, image_loader, tiff);
+
+#ifndef EVAS_STATIC_BUILD_TIFF
+EVAS_EINA_MODULE_DEFINE(image_loader, tiff);
+#endif
